/*
 * Template functions file.
 */
jQuery(function () {
	"use strict";

	var screen_has_mouse = false;
	var $body = jQuery("body");
	var $top = jQuery("#top-header");
	var $adminbar = jQuery("#wpadminbar");
	var $header_title = jQuery("#header-title");
	var $featured = jQuery("#featured");
	var $site_content = jQuery("#content");
	var animCSSDuration = $body.prop("--wp--custom--duration--animation--normal");
	var transitionCSSDuration = $body.prop("--wp--custom--duration--transition");
	var animMiliseconds = 1000;
	var transitionMiliseconds = 500;
	var submenuTopLimit;
	var triggerResize = false;
	var triggerScroll = false;

	if (animCSSDuration) {
		animMiliseconds = parseInt(
			parseFloat(animCSSDuration) *
				(animCSSDuration.indexOf("ms") !== -1 ? 1 : 1000),
			10,
		);
	}

	if (transitionCSSDuration) {
		transitionMiliseconds = parseInt(
			parseFloat(transitionCSSDuration) *
				(transitionCSSDuration.indexOf("ms") !== -1 ? 1 : 1000),
			10,
		);
	}

	// Simple way of determining if user is using a mouse device.
	function themeMouseMove() {
		screen_has_mouse = true;
	}
	function themeTouchStart() {
		jQuery(window).off("mousemove.katerina");
		screen_has_mouse = false;
		setTimeout(function () {
			jQuery(window).on("mousemove.katerina", themeMouseMove);
		}, 250);
	}
	if (
		!navigator.userAgent.match(
			/(Android|webOS|iPhone|iPad|iPod|BlackBerry|IEMobile|Opera Mini)/g,
		)
	) {
		jQuery(window)
			.on("touchstart.katerina", themeTouchStart)
			.on("mousemove.katerina", themeMouseMove);
		if (window.navigator.msPointerEnabled) {
			document.addEventListener("MSPointerDown", themeTouchStart, false);
		}
	}

	// Handle both mouse hover and touch events for traditional menu + mobile hamburger.
	jQuery("#menu-toggle").on("click.katerina", function (e) {
		$body.toggleClass("mobile-menu-opened");
		e.stopPropagation();
		e.preventDefault();

		if (
			$body.hasClass("mobile-menu-opened") &&
			$featured.length > 0 &&
			window.scrollY < $featured.outerHeight() / 2
		) {
			var adminbar_diff =
				$adminbar.length > 0 && "fixed" === $adminbar.css("position")
					? $adminbar.outerHeight()
					: 0;
			scrollTo($top.offset().top - adminbar_diff, animMiliseconds);
		}
	});

	jQuery(
		".main-navigation .current-menu-parent, .main-navigation .current-menu-ancestor",
	).addClass("collapse");

	jQuery(document).on(
		{
			mouseenter: function () {
				if (screen_has_mouse) {
					jQuery(this).addClass("hover");
				}
			},
			mouseleave: function () {
				if (screen_has_mouse) {
					jQuery(this).removeClass("hover");
				}
			},
		},
		".main-navigation li:not(.menu-item-scheme,.menu-item-cart,.menu-item-search)",
	);

	if (jQuery("html").hasClass("touchevents")) {
		jQuery(".main-navigation .menu-item-has-children > a").on(
			"click.katerina",
			function (e) {
				if (
					!screen_has_mouse &&
					!window.navigator.msPointerEnabled &&
					!jQuery("#menu-toggle").is(":visible")
				) {
					if (!jQuery(this).parents(".hover").length) {
						jQuery(".site-header .menu .menu-item-has-children")
							.not(jQuery(this).parent())
							.removeClass("hover");
					}
					jQuery(this).parent().toggleClass("hover");
					e.preventDefault();
				}
			},
		);
	} else {
		// Toggle visibility of dropdowns on keyboard focus events.
		jQuery(".main-navigation li > a, .site-identity a, #search-form-input").on(
			"focus.katerina blur.katerina",
			function (e) {
				if (screen_has_mouse && !jQuery("#menu-toggle").is(":visible")) {
					if (!jQuery(this).parents(".hover").length) {
						jQuery(".main-navigation .menu-item-has-children.hover")
							.not(jQuery(this).parent())
							.removeClass("hover");
					}
					if (jQuery(this).parent().hasClass("menu-item-has-children")) {
						jQuery(this).parent().addClass("hover");
					}
					e.preventDefault();
				}
			},
		);
	}

	// Toggle visibility of dropdowns if touched outside the menu area.
	jQuery(document).on("click.katerina", function (e) {
		if (jQuery(e.target).parents(".main-navigation").length > 0) {
			return;
		}
		jQuery(".main-navigation .menu-item-has-children.hover").removeClass(
			"hover",
		);
		$body.removeClass("searchform-opened");
	});

	jQuery(".main-navigation .menu-item-has-children > a").on(
		"click.katerina",
		function (e) {
			if (jQuery("#menu-toggle").is(":visible")) {
				jQuery(this).parent().toggleClass("collapse");
				e.preventDefault();
			}
		},
	);

	// Toggle scheme (default or alt).
	jQuery(".main-navigation .menu-item-scheme > a").on(
		"click.katerina",
		function (e) {
			var current_scheme = jQuery("html").attr("data-scheme");
			if (!current_scheme || "default" === current_scheme) {
				current_scheme = "alt";
			} else {
				current_scheme = "default";
			}
			jQuery("html").attr("data-scheme", current_scheme);
			localStorage.setItem("colorSchemeKaterina", current_scheme);
			e.stopPropagation();
			e.preventDefault();
		},
	);

	// Toggle visibility of search form in primary menu.
	jQuery(".main-navigation .menu-item-search > a").on(
		"click.katerina",
		function (e) {
			$body.toggleClass("searchform-opened");
			if ($body.hasClass("searchform-opened")) {
				window.setTimeout(function () {
					jQuery(".main-navigation .searchform input[type=search]").focus();
				}, 150);
			}
			e.stopPropagation();
			e.preventDefault();
		},
	);

	// Hide search form if ESC character is pressed
	jQuery(".main-navigation .searchform input[type=search] ").on(
		"keyup",
		function (e) {
			if (27 === e.keyCode) {
				$body.removeClass("searchform-opened");
			}
		},
	);

	// Handle navigation stickiness.
	if ($body.hasClass("navbar-sticky") && !$body.hasClass("error404")) {
		var top_nav_height;
		var stickyTopLimit;
		var isSticky;
		var $marginContainer = $top.next();

		var update_sticky_nav_variables = function () {
			top_nav_height = $top.outerHeight();
			if ($featured.length > 0) {
				stickyTopLimit = $featured.outerHeight() - top_nav_height;
				if ($adminbar.length > 0 && "fixed" === $adminbar.css("position")) {
					stickyTopLimit -= $adminbar.outerHeight();
				}
			} else {
				stickyTopLimit = 0;
			}
			if (Number.isNaN(stickyTopLimit)) {
				stickyTopLimit = 0;
			}
		};

		jQuery(window).on("resize.katerina", function () {
			if (!jQuery("#menu-toggle").is(":visible")) {
				isSticky = $body.hasClass("navbar-is-sticky");
				$body.removeClass("navbar-is-sticky");
				update_sticky_nav_variables();
				if (isSticky) {
					$body.addClass("navbar-is-sticky");
				}

				// On scroll, we want to stick/unstick the navigation.
				if (!$top.hasClass("navbar-sticky-watching")) {
					$top.addClass("navbar-sticky-watching");
					jQuery(window).on("scroll.katerina", function () {
						isSticky = $body.hasClass("navbar-is-sticky");
						if (window.scrollY >= stickyTopLimit) {
							if (!isSticky) {
								$body.addClass("navbar-is-sticky");
								if (
									parseInt($marginContainer.css("margin-top"), 10) !==
									top_nav_height
								) {
									$marginContainer.css("margin-top", top_nav_height);
								}
							}
						} else {
							if (isSticky) {
								$body.removeClass("navbar-is-sticky");
								$marginContainer.css("margin-top", "");
							}
						}
					});
				}
			} else {
				if ($top.hasClass("navbar-sticky-watching")) {
					$top.removeClass("navbar-sticky-watching");
					jQuery(window).unbind("scroll.katerina");
					$body.removeClass("navbar-is-sticky");
					$marginContainer.css("margin-top", "");
				}
			}
		});
		triggerResize = true;
		triggerScroll = true;
	}

	// Performant smooth scrolling using requestAnimationFrame
	function scrollTo(yPos, animDuration = 1000) {
		var startY = window.scrollY;
		var difference = yPos - startY;
		var startTime = window.performance.now();

		function scrollStep() {
			var progress = (window.performance.now() - startTime) / animDuration - 1;
			var amount = progress * progress * progress + 1; // easeOutCubic
			window.scrollTo({ top: startY + amount * difference });
			if (progress < 0) {
				window.requestAnimFrame(scrollStep);
			}
		}
		scrollStep();
	}

	// Scroll to header functionality.
	jQuery("#scroll-to-header").on("click.katerina", function (e) {
		e.preventDefault();
		var $target = jQuery(jQuery(this).attr("href"));
		var adminbar_diff =
			$adminbar.length > 0 && "fixed" === $adminbar.css("position")
				? $adminbar.outerHeight()
				: 0;
		scrollTo($target.offset().top - adminbar_diff, animMiliseconds);
	});

	// Toggle go-to-top visibility and avoid using any event on mobile devices (for better performance).
	if (jQuery("#scroll-to-top").length > 0) {
		var goToTopLimit = 0;

		// Scroll to top functionality.
		jQuery("#scroll-to-top").on("click.katerina", function (e) {
			e.preventDefault();
			scrollTo(0, animMiliseconds);
		});

		jQuery(window).on("resize.to-top-katerina", function () {
			if (window.innerWidth >= 768) {
				if ($featured.length > 0) {
					goToTopLimit = $featured.outerHeight() + $header_title.outerHeight();
				} else {
					goToTopLimit = $top.outerHeight() + $header_title.outerHeight();
				}
				if (!jQuery("#scroll-to-top").hasClass("watching")) {
					jQuery("#scroll-to-top").addClass("watching");
					jQuery(window).on("scroll.to-top-katerina", function () {
						jQuery("#scroll-to-top").toggleClass(
							"active",
							jQuery(window).scrollTop() > goToTopLimit,
						);
					});
				}
			} else {
				if (jQuery("#scroll-to-top").hasClass("watching")) {
					jQuery("#scroll-to-top").removeClass("watching");
					jQuery(window).unbind("scroll.to-top-katerina");
				}
			}
		});
		triggerResize = true;
		triggerScroll = true;
	}

	/* Don't allow form submittion when commenting with an empty message. */
	jQuery("#commentform").submit(function (ev) {
		var should_return = false;
		jQuery(
			"#commentform #comment, #commentform #author, #commentform #email",
		).each(function (innerEv) {
			if ("" === jQuery.trim(jQuery(this).val())) {
				jQuery(this).focus();
				should_return = true;
				return false;
			}
		});
		if (should_return) {
			return false;
		}
	});

	// Handle parallax effect when hovering on a specific element
	jQuery(
		".theme-parallax .parallax-hover, .theme-parallax .parallax-hover-children > *",
	).on("mousemove", function (e) {
		if (!screen_has_mouse || jQuery("#menu-toggle").is(":visible")) {
			return;
		}
		var r;
		if (screen_has_mouse) {
			r = this.getBoundingClientRect();
			this.style.setProperty(
				"--hoverX",
				e.clientX - (r.left + Math.floor(r.width / 2)),
			);
			this.style.setProperty(
				"--hoverY",
				e.clientY - (r.top + Math.floor(r.height / 2)),
			);
		}
	});

	jQuery(".katerina-gallery .output-type a").on("click", function (e) {
		var current_type = jQuery(this).siblings(".is-active").data("type");
		var new_type = jQuery(this).data("type");
		var $gallery = jQuery(this).parents(".katerina-gallery");
		var old_class = $gallery.attr("class");

		e.preventDefault();
		if (jQuery(this).hasClass("is-active")) {
			return;
		}

		jQuery(this).addClass("is-active").siblings().removeClass("is-active");
		$gallery.attr(
			"class",
			old_class.replace(current_type, new_type) + " make-transition",
		);

		setTimeout(function () {
			$gallery.removeClass("make-transition");
		}, transitionMiliseconds);
	});

	// Handle project gallery filters
	jQuery(".katerina-gallery .output-filter a").on(
		"click.katerina",
		function (e) {
			e.preventDefault();
			if (jQuery(this).hasClass("is-active")) {
				return;
			}

			jQuery(this).parents(".output-filter").find("a").removeClass("is-active");
			jQuery(this).addClass("is-active");

			var $gallery = jQuery(this).parents(".katerina-gallery");
			var $projects = $gallery.find(".katerina-gallery-entry");
			var filter = jQuery(this).data("filters");
			$projects.removeClass("filtered-gallery-entry");
			if ("*" !== filter) {
				$projects
					.filter(':not([data-filters*="' + filter + '"])')
					.addClass("filtered-gallery-entry");
			}

			// scroll to first visible project
			var scrollTop = -1;
			if ($gallery.hasClass("style-dashboard")) {
				scrollTop =
					$projects.filter(":not(.filtered-gallery-entry)").eq(0).offset().top -
					jQuery(this).parents(".output-filter").outerHeight();
				if (
					$body.hasClass("navbar-sticky") &&
					!jQuery("#menu-toggle").is(":visible")
				) {
					scrollTop -= $top.outerHeight();
				}
			} else {
				scrollTop = $gallery.offset().top;
				if (jQuery("#menu-toggle").is(":visible")) {
					scrollTop -= jQuery(this).parents(".output-filter").outerHeight();
				} else {
					scrollTop -= $top.outerHeight();
				}
			}
			if (scrollTop >= 0) {
				var adminbar_diff =
					$adminbar.length > 0 && "fixed" === $adminbar.css("position")
						? $adminbar.outerHeight()
						: 0;
				scrollTo(scrollTop - adminbar_diff, animMiliseconds);
			}
		},
	);

	// toggle visibility of the window and disable some features while window/tab is inactive (for performance and battery life)
	jQuery(document).on("visibilitychange", function (event) {
		$body.toggleClass(
			"document-is-inactive",
			document.visibilityState === "hidden",
		);
	});

	// Handle featured media, be it static image/video or a displacement effect slider
	if ($featured.length > 0) {
		if (jQuery("#featured-slider.type-image > img").length === 1) {
			jQuery("#featured-slider > img").imgHasLoaded(function () {
				$body.addClass("featured-media-loaded");
			});
		} else if (jQuery("#featured-slider.type-video > video").length === 1) {
			jQuery("#featured-slider video")
				.on("loadeddata", function () {
					$body.addClass("featured-media-loaded");
				})
				.on("error", function () {
					$body.addClass("featured-media-loaded");
				});
			if (jQuery("#featured-slider video")[0].readyState >= 3) {
				$body.addClass("featured-media-loaded featured-media-error");
			}
		} else if (jQuery("#featured-slider.type-iframe > iframe").length === 1) {
			jQuery("#featured-slider iframe").on("load", function () {
				$body.addClass("featured-media-loaded");
			});
		} else if (
			jQuery("#featured-slider.type-displacement > .slide.is-active").length > 0
		) {
			jQuery("#featured-slider .slide.is-active > img").imgHasLoaded(
				function () {
					if (jQuery.fn.displacementSlider) {
						jQuery("#featured-slider").displacementSlider();
					}
					$body.addClass("featured-media-loaded");
				},
			);
		} else {
			// handle user custom solution
			$body.addClass("featured-media-loaded");
		}

		var featuredVisibilityState = true;
		function checkSliderVisibility() {
			var newState = $featured.isInViewport();
			if (newState !== featuredVisibilityState) {
				$body.toggleClass("featured-media-hidden", !newState);
				if (
					jQuery("#featured-slider.type-video > video[autoplay]").length === 1
				) {
					if (newState) {
						jQuery("#featured-slider video")[0].play();
					} else {
						jQuery("#featured-slider video")[0].pause();
					}
				}
			}
			featuredVisibilityState = newState;
		}

		// Determine if sub-menus are showed above or below the top header
		submenuTopLimit = $featured.outerHeight() / 2;
		jQuery(window).on("resize.submenu-katerina", function () {
			if (window.innerWidth >= 992) {
				submenuTopLimit = $featured.outerHeight() / 2;
			}
			checkSliderVisibility();
		});

		var resizeFeaturedTimer,
			initialDelay = 0;
		jQuery(window).on("resize.katerina-featured", function () {
			clearTimeout(resizeFeaturedTimer);
			resizeFeaturedTimer = setTimeout(function () {
				initialDelay = transitionMiliseconds;
				var genericInfoHeight = jQuery(
					".featured-media .generic-information",
					$featured,
				).outerHeight();
				if ("undefined" === typeof genericInfoHeight) {
					genericInfoHeight = 0;
				}
				$body.css({
					"--spacing--featured-generic-height": genericInfoHeight + "px",
					"--spacing--featured-nav-height": $top.outerHeight() + "px",
				});
			}, initialDelay);
		});
		triggerResize = true;

		jQuery(window).on("scroll.submenu-katerina", function () {
			$body.toggleClass(
				"submenu-above",
				jQuery(window).scrollTop() < submenuTopLimit,
			);
			checkSliderVisibility();
		});
		triggerScroll = true;
	}

	jQuery(".quantity .decrease, .quantity .increase").on("click", function (e) {
		var $input = jQuery(this).parents(".quantity").find("input[type=number]");
		var min = $input.attr("min");
		var max = $input.attr("max");
		var oldValue = parseFloat($input.val());
		if (!oldValue) {
			oldValue = parseFloat($input.attr("placeholder"));
			if (!oldValue) {
				oldValue = 0;
			}
		}
		var newVal;

		if (jQuery(this).hasClass("decrease")) {
			if (!min) {
				min = 1;
			}
			if (oldValue <= min) {
				return;
			} else {
				newVal = oldValue - 1;
			}
		} else {
			if (!max) {
				max = Number.MAX_SAFE_INTEGER;
			}
			if (oldValue >= max) {
				return;
			} else {
				newVal = oldValue + 1;
			}
		}

		$input.val(newVal).trigger("change");

		e.preventDefault();
		e.stopPropagation();
	});

	if (triggerResize) {
		jQuery(window).trigger("resize");
	}
	if (triggerScroll) {
		jQuery(window).trigger("scroll");
	}
});

window.requestAnimFrame = (function () {
	return (
		window.requestAnimationFrame ||
		window.webkitRequestAnimationFrame ||
		window.mozRequestAnimationFrame ||
		window.oRequestAnimationFrame ||
		window.msRequestAnimationFrame ||
		function (callback) {
			window.setTimeout(callback, 1000 / 60);
		}
	);
})();

(function ($) {
	$.fn.imgHasLoaded = function (callback) {
		return this.each(function () {
			if (this.complete && this.naturalWidth) {
				callback.apply(this);
			} else {
				$(this).on("load", function () {
					callback.apply(this);
				});
			}
		});
	};

	$.fn.isInViewport = function () {
		var elementTop = $(this).offset().top;
		var elementBottom = elementTop + $(this).outerHeight();
		var viewportTop = $(window).scrollTop();
		var viewportBottom = viewportTop + window.innerHeight;
		return elementBottom > viewportTop && elementTop < viewportBottom;
	};
})(jQuery);
