<?php
/**
 * Add any additional CSS style specific to the theme.
 */

function katerina_inline_theme_style() {
	$custom_css = '';

	$custom_css_vars = katerina_get_custom_css_variables();
	if ( $custom_css_vars ) {
		$custom_css = 'body {' . $custom_css_vars . ' }';

		if ( false !== strpos( $custom_css_vars, 'selection--background' ) || false !== strpos( $custom_css_vars, 'selection--foreground' ) ) {
			$custom_css .= ' ::-moz-selection { background-color: var(--wp--custom--color--selection--background); color: var(--wp--custom--color--selection--foreground); } ::selection { background-color: var(--wp--custom--color--selection--background); color: var(--wp--custom--color--selection--foreground); }';
		}
		if ( false !== strpos( $custom_css_vars, 'scrollbar--thumb' ) || false !== strpos( $custom_css_vars, 'scrollbar--track' ) ) {
			$custom_css .= '@media screen and (-webkit-min-device-pixel-ratio: 0) { ::-webkit-scrollbar { width: var(--wp--custom--spacing--scrollbar-track--mobile); height: var(--wp--custom--spacing--scrollbar-track--mobile); } ::-webkit-scrollbar-track { background-color: var(--wp--custom--color--scrollbar--track); } ::-webkit-scrollbar-thumb { background-color: var(--wp--custom--color--scrollbar--thumb); } } @media screen and (-webkit-min-device-pixel-ratio: 0) and (min-width: 768px) { ::-webkit-scrollbar { width: var(--wp--custom--spacing--scrollbar-track--tablet); height: var(--wp--custom--spacing--scrollbar-track--tablet); } } @media screen and (-webkit-min-device-pixel-ratio: 0) and (min-width: 1200px) { ::-webkit-scrollbar { width: var(--wp--custom--spacing--scrollbar-track--desktop); height: var(--wp--custom--spacing--scrollbar-track--desktop); } }';
		}
	}

	if ( 0 !== get_theme_mod( 'allow_alt_colors', 0 ) ) {
		$custom_css_vars_alt_colors = katerina_get_custom_css_variables_alt_colors();
		$custom_css .= 'html[data-scheme=alt] body {' . $custom_css_vars_alt_colors . ' }';
	}

	if ( 0 !== get_theme_mod( 'parallax_effect', 0 ) ) {
		$parallax_effect_amount = wp_get_global_settings( array( 'custom', 'parallax', 'amount' ) );
		$parallax_effect_amount_normal = get_theme_mod( 'parallax_effect_amount_normal', $parallax_effect_amount['normal'] );
		$parallax_effect_amount_big = get_theme_mod( 'parallax_effect_amount_big', $parallax_effect_amount['big'] );
		if ( $parallax_effect_amount['normal'] !== $parallax_effect_amount_normal ) {
			$custom_css .= ' body { --wp--custom--parallax--amount--normal: ' . absint( $parallax_effect_amount_normal ) . ' }';
		}
		if ( $parallax_effect_amount['big'] !== $parallax_effect_amount_big ) {
			$custom_css .= ' body { --wp--custom--parallax--amount--big: ' . absint( $parallax_effect_amount_big ) . ' }';
		}
	}

	$typography = wp_get_global_settings( array( 'custom', 'typography' ) );
	$custom_css .= ' html { font-size: ' . $typography['fontSize']['normal'] . '; }';

	if ( ! empty( $custom_css ) ) {
		// properly escape CSS allowing ONLY direct child " > " CSS selector.
		if ( is_child_theme() ) {
			$theme_id = 'katerina-child';
		} else {
			$theme_id = 'katerina';
		}
		wp_add_inline_style( $theme_id, str_replace( ' &gt; ', ' > ', wp_kses( ltrim( $custom_css ), array( '\'', '\"' ) ) ) );
	}
}
add_action( 'wp_enqueue_scripts', 'katerina_inline_theme_style' );

// Enqueue block editor style
function katerina_block_editor_styles() {
	$katerina_theme_version  = wp_get_theme()->get( 'Version' );
	$main_style_dependencies = array();
	wp_enqueue_style( 'katerina-block-editor-style', get_template_directory_uri() . '/assets/css/block-editor.css', $main_style_dependencies, $katerina_theme_version );

	$custom_css_vars = katerina_get_custom_css_variables();
	if ( $custom_css_vars ) {
		$custom_css = '#editor .editor-styles-wrapper {' . $custom_css_vars . ' }';
		// properly escape CSS allowing ONLY direct child " > " CSS selector.
		wp_add_inline_style( 'katerina-block-editor-style', str_replace( ' &gt; ', ' > ', wp_kses( ltrim( $custom_css ), array( '\'', '\"' ) ) ) );
	}
}
add_action( 'enqueue_block_editor_assets', 'katerina_block_editor_styles' );

/*
 * Collect CSS variables from theme options.
 */
function katerina_get_custom_css_variables() {
	$custom_css_variables = '';

	$theme_colors = katerina_theme_colors();
	foreach ( $theme_colors as $key => $color ) {
		$color_mod = get_theme_mod( $color['slug'], $color['default'] );
		if ( $color_mod && $color['default'] != $color_mod ) {
			$custom_css_variables .= ' ' . $color['variable'] . ": {$color_mod};";
		}
	}

	return $custom_css_variables;
}

/*
 * Collect only alternative CSS variables from theme options.
 */
function katerina_get_custom_css_variables_alt_colors() {
	$custom_css_variables = '';

	$theme_colors = katerina_theme_colors();
	foreach ( $theme_colors as $key => $color ) {
		$color_mod = get_theme_mod( $color['slug'] . '__alt', '' );
		if ( $color_mod && '' !== $color_mod ) {
			$custom_css_variables .= ' ' . $color['variable'] . ": {$color_mod};";
		}
	}

	return $custom_css_variables;
}

/*
 * A list of colors that are available in the Customize > Colors section.
 */
function katerina_theme_colors() {
	$all_colors = array();
	$preset_var = '--wp--preset--color--';
	$custom_var = '--wp--custom--color--';

	$settings       = wp_get_global_settings();
	$palette_colors = $settings['color']['palette']['theme'];
	$custom_colors  = $settings['custom']['color'];

	// get colors from theme.json palette
	foreach ( $palette_colors as $key => $color ) {
		$all_colors[ $color['slug'] ] = array(
			'slug'     => 'color_' . $color['slug'],
			'variable' => $preset_var . $color['slug'],
			'default'  => $color['color'],
			'label'    => $color['name'],
			'priority' => 5,
		);
	}

	// and also from the custom section of the same file
	$all_colors['page-border'] = array(
		'slug'     => 'color_page_border',
		'variable' => $custom_var . 'page-border',
		'default'  => katerina_default_from_preset_custom( $custom_colors['pageBorder'], $all_colors, $custom_colors, $preset_var, $custom_var ),
		'label'    => esc_html__( 'Page Border', 'katerina' ),
		'priority' => 11,
	);

	$all_colors['primary-alt'] = array(
		'slug'     => 'color_primary_alt',
		'variable' => $custom_var . 'primary-alt',
		'default'  => katerina_default_from_preset_custom( $custom_colors['primaryAlt'], $all_colors, $custom_colors, $preset_var, $custom_var ),
		'label'    => esc_html__( 'Primary Contrast', 'katerina' ),
		'priority' => 12,
	);

	$all_colors['secondary-alt'] = array(
		'slug'     => 'color_secondary_alt',
		'variable' => $custom_var . 'secondary-alt',
		'default'  => katerina_default_from_preset_custom( $custom_colors['secondaryAlt'], $all_colors, $custom_colors, $preset_var, $custom_var ),
		'label'    => esc_html__( 'Secondary Contrast', 'katerina' ),
		'priority' => 12,
	);

	$all_colors['tertiary-alt'] = array(
		'slug'     => 'color_tertiary_alt',
		'variable' => $custom_var . 'tertiary-alt',
		'default'  => katerina_default_from_preset_custom( $custom_colors['tertiaryAlt'], $all_colors, $custom_colors, $preset_var, $custom_var ),
		'label'    => esc_html__( 'Tertiary Contrast', 'katerina' ),
		'priority' => 12,
	);

	$all_colors['footer--background'] = array(
		'slug'     => 'footer_background',
		'variable' => $custom_var . 'footer--background',
		'default'  => '',
		'label'    => esc_html__( 'Footer Background', 'katerina' ),
		'priority' => 12,
	);

	$all_colors['footer--foreground'] = array(
		'slug'     => 'footer_foreground',
		'variable' => $custom_var . 'footer--foreground',
		'default'  => '',
		'label'    => esc_html__( 'Footer Foreground', 'katerina' ),
		'priority' => 12,
	);

	$all_colors['submenu--background'] = array(
		'slug'     => 'submenu_background',
		'variable' => $custom_var . 'submenu--background',
		'default'  => '',
		'label'    => esc_html__( 'Submenu Background', 'katerina' ),
		'priority' => 12,
	);

	$all_colors['submenu--foreground'] = array(
		'slug'     => 'submenu_foreground',
		'variable' => $custom_var . 'submenu--foreground',
		'default'  => '',
		'label'    => esc_html__( 'Submenu Foreground', 'katerina' ),
		'priority' => 12,
	);

	$all_colors['selection--background'] = array(
		'slug'         => 'selection_background',
		'variable'     => $custom_var . 'selection--background',
		'default'      => '',
		'show_opacity' => true,
		'label'        => esc_html__( 'Selection Background', 'katerina' ),
		'priority'     => 12,
	);

	$all_colors['selection--foreground'] = array(
		'slug'         => 'selection_foreground',
		'variable'     => $custom_var . 'selection--foreground',
		'default'      => '',
		'show_opacity' => true,
		'label'        => esc_html__( 'Selection Foreground', 'katerina' ),
		'priority' => 12,
	);

	$all_colors['scrollbar--thumb'] = array(
		'slug'     => 'scrollbar_thumb',
		'variable' => $custom_var . 'scrollbar--thumb',
		'default'  => '',
		'label'    => esc_html__( 'Scrollbar Thumb', 'katerina' ),
		'priority' => 12,
	);

	$all_colors['scrollbar--track'] = array(
		'slug'     => 'scrollbar_track',
		'variable' => $custom_var . 'scrollbar--track',
		'default'  => '',
		'label'    => esc_html__( 'Scrollbar Track', 'katerina' ),
		'priority' => 12,
	);

	$all_colors['button--regular--background'] = array(
		'slug'     => 'button_regular_background',
		'variable' => $custom_var . 'button--regular--background',
		'default'  => '',
		'label'    => esc_html__( 'Button Regular Background', 'katerina' ),
		'priority' => 12,
	);

	$all_colors['button--regular--foreground'] = array(
		'slug'     => 'button_regular_foreground',
		'variable' => $custom_var . 'button--regular--foreground',
		'default'  => '',
		'label'    => esc_html__( 'Button Regular Foreground', 'katerina' ),
		'priority' => 12,
	);

	$all_colors['button--regular--border'] = array(
		'slug'     => 'button_regular_border',
		'variable' => $custom_var . 'button--regular--border',
		'default'  => '',
		'label'    => esc_html__( 'Button Regular Border', 'katerina' ),
		'priority' => 12,
	);

	$all_colors['button--hover--background'] = array(
		'slug'     => 'button_hover_background',
		'variable' => $custom_var . 'button--hover--background',
		'default'  => '',
		'label'    => esc_html__( 'Button Hover Background', 'katerina' ),
		'priority' => 12,
	);

	$all_colors['button--hover--foreground'] = array(
		'slug'     => 'button_hover_foreground',
		'variable' => $custom_var . 'button--hover--foreground',
		'default'  => '',
		'label'    => esc_html__( 'Button Hover Foreground', 'katerina' ),
		'priority' => 12,
	);

	$all_colors['button--hover--border'] = array(
		'slug'     => 'button_hover_border',
		'variable' => $custom_var . 'button--hover--border',
		'default'  => '',
		'label'    => esc_html__( 'Button Hover Border', 'katerina' ),
		'priority' => 12,
	);

	$all_colors['input--regular--background'] = array(
		'slug'     => 'input_regular_background',
		'variable' => $custom_var . 'input--regular--background',
		'default'  => '',
		'label'    => esc_html__( 'Input Regular Background', 'katerina' ),
		'priority' => 12,
	);

	$all_colors['input--regular--foreground'] = array(
		'slug'     => 'input_regular_foreground',
		'variable' => $custom_var . 'input--regular--foreground',
		'default'  => '',
		'label'    => esc_html__( 'Input Regular Foreground', 'katerina' ),
		'priority' => 12,
	);

	$all_colors['input--regular--border'] = array(
		'slug'     => 'input_regular_border',
		'variable' => $custom_var . 'input--regular--border',
		'default'  => '',
		'label'    => esc_html__( 'Input Regular Border', 'katerina' ),
		'priority' => 12,
	);

	$all_colors['input--focus--background'] = array(
		'slug'     => 'input_focus_background',
		'variable' => $custom_var . 'input--focus--background',
		'default'  => '',
		'label'    => esc_html__( 'Input Focus Background', 'katerina' ),
		'priority' => 12,
	);

	$all_colors['input--focus--foreground'] = array(
		'slug'     => 'input_focus_foreground',
		'variable' => $custom_var . 'input--focus--foreground',
		'default'  => '',
		'label'    => esc_html__( 'Input Focus Foreground', 'katerina' ),
		'priority' => 12,
	);

	$all_colors['input--focus--border'] = array(
		'slug'     => 'input_focus_border',
		'variable' => $custom_var . 'input--focus--border',
		'default'  => '',
		'label'    => esc_html__( 'Input Focus Border', 'katerina' ),
		'priority' => 12,
	);

	$all_colors['input--required'] = array(
		'slug'     => 'input_required',
		'variable' => $custom_var . 'input--required',
		'default'  => katerina_default_from_preset_custom( $custom_colors['input']['required'], $all_colors, $custom_colors, $preset_var, $custom_var ),
		'label'    => esc_html__( 'Input Required', 'katerina' ),
		'priority' => 12,
	);

	$all_colors['input--outline--normal'] = array(
		'slug'         => 'input_outline_normal',
		'variable'     => $custom_var . 'input--outline--normal',
		'default'      => katerina_default_from_preset_custom( $custom_colors['input']['outline']['normal'], $all_colors, $custom_colors, $preset_var, $custom_var ),
		'show_opacity' => true,
		'label'        => esc_html__( 'Input Outline Normal', 'katerina' ),
		'priority'     => 12,
	);

	$all_colors['input--outline--required'] = array(
		'slug'         => 'input_outline_required',
		'variable'     => $custom_var . 'input--outline--required',
		'default'      => katerina_default_from_preset_custom( $custom_colors['input']['outline']['required'], $all_colors, $custom_colors, $preset_var, $custom_var ),
		'show_opacity' => true,
		'label'        => esc_html__( 'Input Outline Required', 'katerina' ),
		'priority' => 12,
	);

	$all_colors['overlay--normal--background'] = array(
		'slug'         => 'overlay_normal_background',
		'variable'     => $custom_var . 'overlay--normal--background',
		'default'      => katerina_default_from_preset_custom( $custom_colors['overlay']['normal']['background'], $all_colors, $custom_colors, $preset_var, $custom_var ),
		'show_opacity' => true,
		'label'        => esc_html__( 'Overlay Normal Background', 'katerina' ),
		'priority'     => 12,
	);

	$all_colors['overlay--normal--foreground'] = array(
		'slug'         => 'overlay_normal_foreground',
		'variable'     => $custom_var . 'overlay--normal--foreground',
		'default'      => katerina_default_from_preset_custom( $custom_colors['overlay']['normal']['foreground'], $all_colors, $custom_colors, $preset_var, $custom_var ),
		'show_opacity' => true,
		'label'        => esc_html__( 'Overlay Normal Foreground', 'katerina' ),
		'priority'     => 12,
	);

	$all_colors['overlay--inverted--background'] = array(
		'slug'         => 'overlay_inverted_background',
		'variable'     => $custom_var . 'overlay--inverted--background',
		'default'      => katerina_default_from_preset_custom( $custom_colors['overlay']['inverted']['background'], $all_colors, $custom_colors, $preset_var, $custom_var ),
		'show_opacity' => true,
		'label'        => esc_html__( 'Overlay Inverted Background', 'katerina' ),
		'priority'     => 12,
	);

	$all_colors['overlay--inverted--foreground'] = array(
		'slug'         => 'overlay_inverted_foreground',
		'variable'     => $custom_var . 'overlay--inverted--foreground',
		'default'      => katerina_default_from_preset_custom( $custom_colors['overlay']['inverted']['foreground'], $all_colors, $custom_colors, $preset_var, $custom_var ),
		'show_opacity' => true,
		'label'        => esc_html__( 'Overlay Inverted Foreground', 'katerina' ),
		'priority'     => 12,
	);

	$all_colors['featured--background'] = array(
		'slug'     => 'featured_background',
		'variable' => $custom_var . 'featured--background',
		'default'  => '',
		'label'    => esc_html__( 'Featured Background', 'katerina' ),
		'priority' => 12,
	);

	$all_colors['featured--foreground'] = array(
		'slug'     => 'featured_foreground',
		'variable' => $custom_var . 'featured--foreground',
		'default'  => '',
		'label'    => esc_html__( 'Featured Foreground', 'katerina' ),
		'priority' => 12,
	);

	$all_colors['featured--text-shadow'] = array(
		'slug'         => 'featured_text_shadow',
		'variable'     => $custom_var . 'featured--text-shadow',
		'default'      => katerina_default_from_preset_custom( $custom_colors['featured']['textShadow'], $all_colors, $custom_colors, $preset_var, $custom_var ),
		'show_opacity' => true,
		'label'        => esc_html__( 'Featured Text Shadow', 'katerina' ),
		'priority'     => 12,
	);

	$all_colors['box-shadow'] = array(
		'slug'         => 'box_shadow',
		'variable'     => $custom_var . 'box-shadow',
		'default'      => katerina_default_from_preset_custom( $custom_colors['box-shadow'], $all_colors, $custom_colors, $preset_var, $custom_var ),
		'show_opacity' => true,
		'label'        => esc_html__( 'Box Shadow', 'katerina' ),
		'priority'     => 12,
	);

	return $all_colors;
}

function katerina_default_from_preset_custom( $default, $all_colors, $custom_colors, $preset_var, $custom_var ) {
	if ( false !== strpos( $default, $preset_var ) ) {
		return $all_colors[ rtrim( substr( $default, strpos( $default, $preset_var ) + strlen( $preset_var ) ), ')' ) ]['default'];
	} else if ( false !== strpos( $default, $custom_var ) ) {
		return $all_colors[ rtrim( substr( $default, strpos( $default, $custom_var ) + strlen( $custom_var ) ), ')' ) ]['default'];
	} else if ( 'transparent' === $default ) {
		return '';
	} else {
		return $default;
	}
}
