<?php
/**
 * Theme Customizer functionality.
 */

/**
 * Adds Customizer settings and controls.
 *
 * @param WP_Customize_Manager $wp_customize Customizer object.
 */
function katerina_customize_register( $wp_customize ) {

	require_once( dirname( __FILE__ ) . '/alpha-color-picker/class-customize-alpha-color-control.php' );
	require_once( dirname( __FILE__ ) . '/image-gallery/class-customize-image-gallery-control.php' );

	// Add postMessage support for the site title and tagline.
	$wp_customize->get_setting( 'blogname' )->transport        = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';

	// The theme doesn't allow any background imageand has custom background color control.
	$wp_customize->remove_section( 'background_image' );
	$wp_customize->remove_setting( 'background_color' );
	$wp_customize->remove_control( 'background_color' );

	// Alternative logo image (for dark mode).
	$wp_customize->add_setting(
		'custom_logo_alt',
		array(
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'absint',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Media_Control(
			$wp_customize,
			'custom_logo_alt',
			array(
				'label'           => esc_html__( 'Alternative Logo', 'katerina' ),
				'description'     => esc_html__( 'Logo used for the alternative dark color scheme.', 'katerina' ),
				'section'         => 'title_tagline',
				'priority'        => 8,
				'mime_type'       => 'image',
				'active_callback' => 'katerina_custom_logo_alt_colors_active',
				'button_labels'   => array(
					'select'       => esc_html__( 'Select logo', 'katerina' ),
					'change'       => esc_html__( 'Change logo', 'katerina' ),
					'placeholder'  => esc_html__( 'No logo selected', 'katerina' ),
					'frame_title'  => esc_html__( 'Select logo', 'katerina' ),
					'frame_button' => esc_html__( 'Choose logo', 'katerina' ),
				),
			)
		)
	);

	/* Style panel */
	$wp_customize->add_panel(
		'style',
		array(
			'title'      => esc_html__( 'Theme Style', 'katerina' ),
			'priority'   => 60,
			'capability' => 'edit_theme_options',
		)
	);

	/* Colors section */
	$wp_customize->add_section(
		'style_colors',
		array(
			'title'      => esc_html__( 'Default Color Scheme', 'katerina' ),
			'panel'      => 'style',
			'capability' => 'edit_theme_options',
		)
	);

	$theme_colors = katerina_theme_colors();
	foreach ( $theme_colors as $key => $color ) {
		if ( isset( $color['priority'] ) ) {
			$priority = $color['priority'];
		} else {
			$priority = 10;
		}
		$wp_customize->add_setting(
			$color['slug'],
			array(
				'default'           => $color['default'],
				'sanitize_callback' => 'katerina_sanitize_color',
			)
		);
		$wp_customize->add_setting(
			$color['slug'] . '__alt',
			array(
				'sanitize_callback' => 'katerina_sanitize_color',
			)
		);
		if ( isset( $color['show_opacity'] ) || false !== strpos( $color['default'], 'rgba' ) ) {
			$wp_customize->add_control(
				new Customize_Alpha_Color_Control(
					$wp_customize,
					$color['slug'],
					array(
						'label'        => $color['label'],
						'section'      => 'style_colors',
						'priority'     => $priority,
						'show_opacity' => true,
					)
				)
			);
			$wp_customize->add_control(
				new Customize_Alpha_Color_Control(
					$wp_customize,
					$color['slug'] . '__alt',
					array(
						'label'           => $color['label'],
						'section'         => 'style_colors_alt',
						'priority'        => $priority,
						'show_opacity'    => true,
						'active_callback' => 'katerina_is_alt_colors_active',
					)
				)
			);
		} else {
			$wp_customize->add_control(
				new WP_Customize_Color_Control(
					$wp_customize,
					$color['slug'],
					array(
						'label'    => $color['label'],
						'section'  => 'style_colors',
						'priority' => $priority,
					)
				)
			);
			$wp_customize->add_control(
				new WP_Customize_Color_Control(
					$wp_customize,
					$color['slug'] . '__alt',
					array(
						'label'           => $color['label'],
						'section'         => 'style_colors_alt',
						'priority'        => $priority,
						'active_callback' => 'katerina_is_alt_colors_active',
					)
				)
			);
		}
	}

	// Add a page border
	$wp_customize->add_setting(
		'page_border',
		array(
			'default'           => 0,
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'absint',
			'transport'         => 'postMessage',
		)
	);
	$wp_customize->add_control(
		'page_border',
		array(
			'label'    => esc_html__( 'Add Page Border', 'katerina' ),
			'settings' => 'page_border',
			'type'     => 'checkbox',
			'section'  => 'style_colors',
			'priority' => 10,
		)
	);
	$wp_customize->get_control( 'color_page_border' )->active_callback = 'katerina_is_page_border_active';

	/* Alternative Colors section */
	$wp_customize->add_section(
		'style_colors_alt',
		array(
			'title'      => esc_html__( 'Alternative Color Scheme', 'katerina' ),
			'panel'      => 'style',
			'capability' => 'edit_theme_options',
		)
	);

	// Allow alternative colors
	$wp_customize->add_setting(
		'allow_alt_colors',
		array(
			'default'           => 0,
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'absint',
		)
	);
	$wp_customize->add_control(
		'allow_alt_colors',
		array(
			'label'       => esc_html__( 'Enabled Alternative Colors', 'katerina' ),
			'description' => esc_html__( 'Allow for an alternative dark color scheme.', 'katerina' ),
			'settings'    => 'allow_alt_colors',
			'section'     => 'style_colors_alt',
			'type'        => 'checkbox',
			'priority'    => 3,
		)
	);

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial(
			'allow_alt_colors',
			array(
				'selector'            => '.main-navigation .menu-item-scheme',
				'container_inclusive' => false,
				'fallback_refresh'    => false,
			)
		);
	}

	// Set alt colors by default
	$wp_customize->add_setting(
		'alt_colors_by_default',
		array(
			'default'           => 0,
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'absint',
		)
	);
	$wp_customize->add_control(
		'alt_colors_by_default',
		array(
			'label'           => esc_html__( 'Alternative Colors By Default', 'katerina' ),
			'description'     => esc_html__( 'The alternative color scheme is enabled by default (instead of the default color scheme).', 'katerina' ),
			'settings'        => 'alt_colors_by_default',
			'section'         => 'style_colors_alt',
			'type'            => 'checkbox',
			'priority'        => 3,
			'active_callback' => 'katerina_is_alt_colors_active',
		)
	);

	/* Additional Options section */
	$wp_customize->add_section(
		'style_additional',
		array(
			'title'      => esc_html__( 'Additional Options', 'katerina' ),
			'panel'      => 'style',
			'capability' => 'edit_theme_options',
		)
	);

	// Default page animation
	$wp_customize->add_setting(
		'page_animation',
		array(
			'default'           => 0,
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'absint',
		)
	);
	$wp_customize->add_control(
		'page_animation',
		array(
			'label'       => esc_html__( 'Default Page Animation', 'katerina' ),
			'description' => esc_html__( 'Determine if pages get a custom animation when loaded.', 'katerina' ),
			'settings'    => 'page_animation',
			'section'     => 'style_additional',
			'priority'    => 20,
			'type'        => 'checkbox',
		)
	);

	// Make the primary menu sticky
	$wp_customize->add_setting(
		'primary_menu_sticky',
		array(
			'default'           => 0,
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'absint',
		)
	);
	$wp_customize->add_control(
		'primary_menu_sticky',
		array(
			'label'       => esc_html__( 'Sticky Top Menu', 'katerina' ),
			'description' => esc_html__( 'Determine if the navigation section is locked into place when scrolling down the page (below the hero section).', 'katerina' ),
			'settings'    => 'primary_menu_sticky',
			'section'     => 'style_additional',
			'priority'    => 20,
			'type'        => 'checkbox',
		)
	);

	// Display search icon in menu.
	$wp_customize->add_setting(
		'primary_menu_has_search',
		array(
			'default'           => 0,
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'absint',
			'transport'         => 'postMessage',
		)
	);
	$wp_customize->add_control(
		'primary_menu_has_search',
		array(
			'label'       => esc_html__( 'Search In Top Menu', 'katerina' ),
			'description' => esc_html__( 'Determine if a search form is displayed in the navigation section.', 'katerina' ),
			'settings'    => 'primary_menu_has_search',
			'section'     => 'style_additional',
			'priority'    => 20,
			'type'        => 'checkbox',
		)
	);

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial(
			'primary_menu_has_search',
			array(
				'selector'            => '.main-navigation .menu-item-search',
				'container_inclusive' => false,
				'fallback_refresh'    => false,
			)
		);
	}

	// Scroll to top button
	$wp_customize->add_setting(
		'scroll_to_top',
		array(
			'default'           => 0,
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'absint',
		)
	);
	$wp_customize->add_control(
		'scroll_to_top',
		array(
			'label'       => esc_html__( 'Scroll To Top', 'katerina' ),
			'description' => esc_html__( 'Show a button in the footer area that will take the user to the top of the page when clicked on.', 'katerina' ),
			'settings'    => 'scroll_to_top',
			'section'     => 'style_additional',
			'priority'    => 20,
			'type'        => 'checkbox',
		)
	);

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial(
			'scroll_to_top',
			array(
				'selector'            => '#scroll-to-top',
				'container_inclusive' => false,
				'fallback_refresh'    => false,
			)
		);
	}

	// Parallax effect
	$wp_customize->add_setting(
		'parallax_effect',
		array(
			'default'           => 0,
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'absint',
		)
	);
	$wp_customize->add_control(
		'parallax_effect',
		array(
			'label'       => esc_html__( 'Parallax Effect', 'katerina' ),
			'description' => esc_html__( 'Determine if some images have a parallax effect on mouse hover (on desktop screens).', 'katerina' ),
			'settings'    => 'parallax_effect',
			'section'     => 'style_additional',
			'priority'    => 20,
			'type'        => 'checkbox',
		)
	);

	// Parallax effect amount normal
	$wp_customize->add_setting(
		'parallax_effect_amount_normal',
		array(
			'default'           => 30,
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'absint',
		)
	);
	$wp_customize->add_control(
		'parallax_effect_amount_normal',
		array(
			'label'       => esc_html__( 'Parallax Amount 1', 'katerina' ),
			'description' => esc_html__( 'Determine the amount of parallax movement for a normal situation (regular images, galleries; bigger means less movement)', 'katerina' ),
			'settings'    => 'parallax_effect_amount_normal',
			'section'     => 'style_additional',
			'priority'    => 20,
			'type'        => 'number',
			'input_attrs' => array(
				'min'  => 20,
				'max'  => 100,
				'step' => 5,
			),
			'active_callback' => 'katerina_is_parallax_effect_active',
		)
	);

	// Parallax effect amount big
	$wp_customize->add_setting(
		'parallax_effect_amount_big',
		array(
			'default'           => 60,
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'absint',
		)
	);
	$wp_customize->add_control(
		'parallax_effect_amount_big',
		array(
			'label'       => esc_html__( 'Parallax Amount 2', 'katerina' ),
			'description' => esc_html__( 'Determine the amount of parallax movement for bigger sections (home slider, home parallax image/video; bigger means less movement).', 'katerina' ),
			'settings'    => 'parallax_effect_amount_big',
			'section'     => 'style_additional',
			'priority'    => 20,
			'type'        => 'number',
			'input_attrs' => array(
				'min'  => 40,
				'max'  => 150,
				'step' => 5,
			),
			'active_callback' => 'katerina_is_parallax_effect_active',
		)
	);

	// Blog listing style
	$wp_customize->add_setting(
		'listing_style',
		array(
			'default'           => '',
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'wp_kses_post',
		)
	);
	$wp_customize->add_control(
		'listing_style',
		array(
			'label'    => esc_html__( 'Blog Listing Style', 'katerina' ),
			'settings' => 'listing_style',
			'section'  => 'style_additional',
			'priority' => 20,
			'type'     => 'select',
			'choices'  => array(
				''        => esc_html__( 'Default', 'katerina' ),
				'columns' => esc_html__( 'Columns', 'katerina' ),
			),
		)
	);

	// Exclude category from blog
	$categories_full_list = get_categories(
		array(
			'orderby'    => 'name',
		)
	);
	$categories_choices_list = array( '' => '' );
	foreach ( $categories_full_list as $single_cat ) {
		$categories_choices_list[ $single_cat->term_id ] = $single_cat->name . ' (' . $single_cat->count . ')';
	}
	$wp_customize->add_setting(
		'exclude_from_blog',
		array(
			'default'           => '',
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'wp_kses_post',
		)
	);
	$wp_customize->add_control(
		'exclude_from_blog',
		array(
			'label'    => esc_html__( 'Exclude From Blog Listing', 'katerina' ),
			'settings' => 'exclude_from_blog',
			'section'  => 'style_additional',
			'priority' => 20,
			'type'     => 'select',
			'choices'  => $categories_choices_list,
		)
	);

	// Footer style
	$wp_customize->add_setting(
		'footer_style',
		array(
			'capability'        => 'edit_theme_options',
			'default'           => 'columns-1',
			'sanitize_callback' => 'wp_kses_post',
		)
	);
	$wp_customize->add_control(
		'footer_style',
		array(
			'label'    => esc_html__( 'Footer Style', 'katerina' ),
			'settings' => 'footer_style',
			'section'  => 'style_additional',
			'priority' => 20,
			'type'     => 'select',
			'choices'  => array(
				'columns-1' => esc_html__( 'No Columns', 'katerina' ),
				'columns-2' => esc_html__( 'Columns - 2', 'katerina' ),
				'columns-3' => esc_html__( 'Columns - 3', 'katerina' ),
				'columns-4' => esc_html__( 'Columns - 4', 'katerina' ),
			),
		)
	);

	// Hide Edit button for admin
	$wp_customize->add_setting(
		'hide_edit_button',
		array(
			'default'           => 0,
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'absint',
		)
	);
	$wp_customize->add_control(
		'hide_edit_button',
		array(
			'label'       => esc_html__( 'Hide Edit Button', 'katerina' ),
			'description' => esc_html__( 'Hide the Edit button displayed for administrators on the frontend.', 'katerina' ),
			'settings'    => 'hide_edit_button',
			'priority'    => 20,
			'section'     => 'style_additional',
			'type'        => 'checkbox',
		)
	);

	// 404 Error Not Found image
	$wp_customize->add_setting(
		'featured_image_404',
		array(
			'default'           => 0,
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'absint',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Media_Control(
			$wp_customize,
			'featured_image_404',
			array(
				'label'     => esc_html__( '404 Not Found Image', 'katerina' ),
				'mime_type' => 'image',
				'priority'  => 30,
				'section'   => 'style_additional',
			)
		)
	);

	/* Footer gallery section */
	$wp_customize->add_section(
		'footer_gallery',
		array(
			'title'      => esc_html__( 'Footer Gallery', 'katerina' ),
			'capability' => 'edit_theme_options',
			'priority'   => 155,
		)
	);

	// Enable footer gallery section
	$wp_customize->add_setting(
		'footer_gallery_active',
		array(
			'default'           => 0,
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'absint',
		)
	);
	$wp_customize->add_control(
		'footer_gallery_active',
		array(
			'label'    => esc_html__( 'Enable Footer Gallery', 'katerina' ),
			'section'  => 'footer_gallery',
			'settings' => 'footer_gallery_active',
			'type'     => 'checkbox',
		)
	);

	// Footer gallery intro
	$wp_customize->add_setting(
		'footer_gallery_intro',
		array(
			'default'           => '',
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'wp_kses_post',
		)
	);
	$wp_customize->add_control(
		'footer_gallery_intro',
		array(
			'label'           => esc_html__( 'Gallery Intro', 'katerina' ),
			'section'         => 'footer_gallery',
			'settings'        => 'footer_gallery_intro',
			'type'            => 'text',
			'active_callback' => 'katerina_is_footer_gallery_active',
		)
	);

	// Footer gallery subtitle
	$wp_customize->add_setting(
		'footer_gallery_subtitle',
		array(
			'default'           => '',
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'wp_kses_post',
		)
	);
	$wp_customize->add_control(
		'footer_gallery_subtitle',
		array(
			'label'           => esc_html__( 'Gallery Subtitle', 'katerina' ),
			'section'         => 'footer_gallery',
			'settings'        => 'footer_gallery_subtitle',
			'type'            => 'text',
			'active_callback' => 'katerina_is_footer_gallery_active',
		)
	);

	// Footer gallery outro
	$wp_customize->add_setting(
		'footer_gallery_outro',
		array(
			'default'           => '',
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'wp_kses_post',
		)
	);
	$wp_customize->add_control(
		'footer_gallery_outro',
		array(
			'label'           => esc_html__( 'Gallery Outro', 'katerina' ),
			'section'         => 'footer_gallery',
			'settings'        => 'footer_gallery_outro',
			'type'            => 'text',
			'active_callback' => 'katerina_is_footer_gallery_active',
		)
	);

	// Footer gallery link
	$wp_customize->add_setting(
		'footer_gallery_link',
		array(
			'default'           => '',
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'esc_url',
		)
	);
	$wp_customize->add_control(
		'footer_gallery_link',
		array(
			'label'           => esc_html__( 'Gallery Link', 'katerina' ),
			'section'         => 'footer_gallery',
			'settings'        => 'footer_gallery_link',
			'type'            => 'text',
			'active_callback' => 'katerina_is_footer_gallery_active',
		)
	);

	// Hide Edit button for admin
	$wp_customize->add_setting(
		'footer_gallery_link_target',
		array(
			'capability'        => 'edit_theme_options',
			'default'           => 1,
			'sanitize_callback' => 'absint',
		)
	);
	$wp_customize->add_control(
		'footer_gallery_link_target',
		array(
			'label'           => esc_html__( 'Open Gallery Link in New Tab/Window', 'katerina' ),
			'section'         => 'footer_gallery',
			'settings'        => 'footer_gallery_link_target',
			'type'            => 'checkbox',
			'active_callback' => 'katerina_is_footer_gallery_active',
		)
	);

	// Footer gallery
	$wp_customize->add_setting(
		'footer_gallery_list',
		array(
			'default'           => '',
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'wp_parse_id_list',
		)
	);
	$wp_customize->add_control(
		new Customize_Image_Gallery_Control(
			$wp_customize,
			'footer_gallery_list',
			array(
				'label'           => esc_html__( 'Gallery Images', 'katerina' ),
				'description'     => esc_html__( 'Manage images that will populate the footer gallery (suggested max. of 10 images).', 'katerina' ),
				'section'         => 'footer_gallery',
				'type'            => 'gallery',
				'active_callback' => 'katerina_is_footer_gallery_active',
			)
		)
	);

}
add_action( 'customize_register', 'katerina_customize_register', 11 );

/**
 * Check if custom logo is enabled and alternative color scheme is enabled.
 */
function katerina_custom_logo_alt_colors_active() {
	return has_custom_logo() && ( 0 !== get_theme_mod( 'allow_alt_colors', 0 ) );
}

/**
 * Determin if the page border color control is visible.
 */
function katerina_is_page_border_active() {
	return 0 !== get_theme_mod( 'page_border', 0 );
}

/**
 * Determin if alternative color scheme is enabled.
 */
function katerina_is_alt_colors_active() {
	return 0 !== get_theme_mod( 'allow_alt_colors', 0 );
}

/**
 * Determin if parallax effect is enabled.
 */
function katerina_is_parallax_effect_active() {
	return 0 !== get_theme_mod( 'parallax_effect', 0 );
}

/**
 * Determin if the footer gallery section and controls are active.
 */
function katerina_is_footer_gallery_active() {
	return 0 !== get_theme_mod( 'footer_gallery_active', 0 );
}

/**
 * Sanitize the opacity value.
 */
function katerina_sanitize_opacity( $input ) {
	return filter_var( $input, FILTER_VALIDATE_INT );
}

/**
 * Sanitize color value.
 */
function katerina_sanitize_color( $value ) {
	// This pattern will check and match 3/6/8-character hex, rgb, rgba, hsl, & hsla colors.
	$pattern = '/^(\#[\da-f]{3}|\#[\da-f]{6}|\#[\da-f]{8}|rgba\(((\d{1,2}|1\d\d|2([0-4]\d|5[0-5]))\s*,\s*){2}((\d{1,2}|1\d\d|2([0-4]\d|5[0-5]))\s*)(,\s*(0\.\d+|1))\)|hsla\(\s*((\d{1,2}|[1-2]\d{2}|3([0-5]\d|60)))\s*,\s*((\d{1,2}|100)\s*%)\s*,\s*((\d{1,2}|100)\s*%)(,\s*(0\.\d+|1))\)|rgb\(((\d{1,2}|1\d\d|2([0-4]\d|5[0-5]))\s*,\s*){2}((\d{1,2}|1\d\d|2([0-4]\d|5[0-5]))\s*)|hsl\(\s*((\d{1,2}|[1-2]\d{2}|3([0-5]\d|60)))\s*,\s*((\d{1,2}|100)\s*%)\s*,\s*((\d{1,2}|100)\s*%)\))$/';
	\preg_match( $pattern, $value, $matches );
	// Return the 1st match found.
	if ( isset( $matches[0] ) ) {
		if ( is_string( $matches[0] ) ) {
			return $matches[0];
		}
		if ( is_array( $matches[0] ) && isset( $matches[0][0] ) ) {
			return $matches[0][0];
		}
	}
	// If no match was found, return an empty string.
	return '';
}

/**
 * Binds JS handlers to make the Customizer preview reload changes asynchronously.
 */
function katerina_customize_preview_js() {
	$katerina_theme_version = wp_get_theme()->get( 'Version' );

	wp_enqueue_script( 'katerina-customize-preview', get_template_directory_uri() . '/assets/js/customize-preview.js', array( 'customize-preview' ), $katerina_theme_version, true );
}
add_action( 'customize_preview_init', 'katerina_customize_preview_js' );

/**
 * Register customize panel controls scripts.
 */
function katerina_customize_controls_register_scripts() {
	$katerina_theme_version = wp_get_theme()->get( 'Version' );

	wp_enqueue_script( 'katerina-customize-callbacks', get_template_directory_uri() . '/assets/js/customize-callbacks.js', array(), $katerina_theme_version, true );
}
add_action( 'customize_controls_enqueue_scripts', 'katerina_customize_controls_register_scripts' );
