<?php
/**
 * Add additional options specific to this theme
 */
function katerina_additional_meta_options_callback() {
	return 'katerina_add_additional_meta_options';
}
add_filter( 'theme_additional_page_meta_box_options_callback', 'katerina_additional_meta_options_callback', 10, 1 );

function katerina_page_meta_box_restrict_template() {
	return false;
}
add_filter( 'theme_additional_page_meta_box_options_restrict_template', 'katerina_page_meta_box_restrict_template', 10, 1 );

function katerina_add_additional_meta_options() {
	global $post;
	$metabox_id = 'katerina-additional-fields';
	wp_nonce_field( "save_{$metabox_id}", "nonce_{$metabox_id}" );
	$template_file = get_post_meta( $post->ID, '_wp_page_template', true );
	?>

	<?php if ( false !== strpos( $template_file, 'template-posts' ) ) : ?>
		<div class="katerina-metabox-field katerina-metabox-field-select">
			<div class="katerina-metabox-label">
				<label for="page_category"><strong><?php esc_html_e( 'Page Category', 'katerina' ); ?></strong></label>
			</div>
			<div class="katerina-metabox-input">
				<?php
					wp_dropdown_categories(
						array(
							'id'              => 'page_category',
							'name'            => 'page_category',
							'selected'        => get_post_meta( $post->ID, 'page_category', true ),
							'orderby'         => 'name',
							'hierarchical'    => true,
							'hide_empty'      => false,
							'show_option_all' => '&nbsp;',
						)
					);
				?>
			</div>
		</div>
	<?php endif; ?>

	<?php $featured_area_type = get_post_meta( $post->ID, 'featured_area_type', true ); ?>
	<div class="katerina-metabox-field katerina-metabox-field-select">
		<div class="katerina-metabox-label">
			<label for="featured_area_type"><strong><?php esc_html_e( 'Featured Area', 'katerina' ); ?></strong></label>
		</div>
		<div class="katerina-metabox-input">
			<select name="featured_area_type" id="featured_area_type">
				<option value=""<?php if ( empty( $featured_area_type ) ) : ?> selected="selected"<?php endif; ?>><?php esc_html_e( 'No Featured Area', 'katerina' ); ?></option>
				<option value="featured"<?php if ( ! empty( $featured_area_type ) && 'featured' === $featured_area_type ) : ?> selected="selected"<?php endif; ?>><?php esc_html_e( 'Use Featured Image', 'katerina' ); ?></option>
				<option value="video"<?php if ( ! empty( $featured_area_type ) && 'video' === $featured_area_type ) : ?> selected="selected"<?php endif; ?>><?php esc_html_e( 'Custom Video', 'katerina' ); ?></option>
				<option value="slider"<?php if ( ! empty( $featured_area_type ) && 'slider' === $featured_area_type ) : ?> selected="selected"<?php endif; ?>><?php esc_html_e( 'Custom Slider', 'katerina' ); ?></option>
				<option value="html"<?php if ( ! empty( $featured_area_type ) && 'html' === $featured_area_type ) : ?> selected="selected"<?php endif; ?>><?php esc_html_e( 'Custom HTML', 'katerina' ); ?></option>
			</select>
		</div>
	</div>

	<?php
	$custom_featured_area = get_post_meta( $post->ID, 'custom_featured_area', true );
	ob_start();
	?>
	<div class="template slider-item slider-item-image">
		<input type="hidden" name="featured_slider_type[]" value="image" disabled="disabled">
		<div class="title">
			<strong><span class="dashicons dashicons-format-image"></span><?php esc_html_e( 'Slide', 'katerina' ); ?></strong>
		</div>
		<a href="#" class="remove-item" title="<?php esc_attr_e( 'Remove Item', 'katerina' ); ?>"><span class="dashicons dashicons-trash"></span></a>
		<div class="inner">
			<div class="image-wrap">
				<a href="#" class="select-image--ATTR1--" data-frame-title="<?php esc_attr_e( 'Edit Slide Image', 'katerina' ); ?>"><span class="dashicons dashicons-edit"></span><span class="description"><?php esc_html_e( 'Image', 'katerina' ); ?></span><img--ATTR2--></a>
				<input type="hidden" name="featured_slider_field1[]" disabled="disabled" value="--VAL1--">
			</div>
			<div class="controls-wrap">
				<textarea name="featured_slider_field2[]" cols="30" rows="5" placeholder="<?php echo esc_attr_x( 'Image caption&hellip;', 'placeholder', 'katerina' ); ?>" disabled="disabled">--VAL2--</textarea>
				<input type="hidden" name="featured_slider_field3[]" disabled="disabled" value="--VAL3--">
			</div>
		</div>
	</div>
	<?php
	$template_slide_image = ob_get_contents();
	ob_end_clean();
	?>
	<div class="katerina-metabox-field katerina-metabox-field-slider"<?php if ( empty( $featured_area_type ) || 'slider' !== $featured_area_type ) : ?> style="display:none"<?php endif; ?>>
		<div class="katerina-metabox-input">
			<input type="hidden" name="custom_featured_area" value="1">
			<?php
			$search = array( '--VAL1--', '--VAL2--', '--VAL3--', '--ATTR1--', '--ATTR2--' );
			$replace = '';
			echo do_shortcode( str_replace( $search, $replace, $template_slide_image ) );
			?>
			<div class="slider-content" data-field-id="custom_featured_area">
				<?php
				if ( ! empty( $custom_featured_area ) ) {
					foreach ( $custom_featured_area as $slide ) {
						switch ( $slide['type'] ) {
							case 'image':
								$search = array( 'template slider-item', ' disabled="disabled"', '--VAL1--', '--VAL2--', '--ATTR1--', '--ATTR2--' );
								$has_image     = isset( $slide['image'] );
								$image_id      = isset( $slide['image'] ) ? $slide['image'] : '';
								$image_caption = isset( $slide['caption'] ) ? $slide['caption'] : '';
								$image_attr    = '';
								if ( $has_image ) {
									$image_attr = ' src="' . esc_attr( wp_get_attachment_image_url( $image_id, 'thumbnail' ) ) . ' "';
								}
								$replace = array( 'slider-item', '', $image_id, $image_caption, ( $has_image ? ' has-image' : '' ), $image_attr );
								echo do_shortcode( str_replace( $search, $replace, $template_slide_image ) );
								break;
						}
					}
				}
				?>
			</div>
			<div class="new-item-actions">
				<strong><?php esc_html_e( 'Add New Slide', 'katerina' ); ?></strong>
				<span class="add-new-popup">
					<a href="#" class="button button-large" data-type="slider-item-image"><span class="dashicons dashicons-format-image"></span><?php esc_html_e( 'Image', 'katerina' ); ?></a>
				</span>
			</div>
		</div>
	</div>

	<div class="katerina-displacement-tweaks"<?php if ( empty( $featured_area_type ) || 'slider' !== $featured_area_type ) : ?> style="display:none"<?php endif; ?>>

		<?php $slider_displacement = get_post_meta( $post->ID, 'slider_displacement', true ); ?>
		<div class="katerina-metabox-field katerina-metabox-field-input">
			<div class="katerina-metabox-label">
				<label for="slider_displacement"><strong><?php esc_html_e( 'Displacement Effect Image', 'katerina' ); ?></strong></label>
			</div>
			<div class="katerina-metabox-input">
				<input type="text" class="image_url regular-text" id="slider_displacement" name="slider_displacement" value="<?php echo esc_attr( $slider_displacement ); ?>"> <button class="button set-image set-file" data-frame-title="<?php esc_html_e( 'Select Displacement Image File', 'katerina' ); ?>"><?php esc_html_e( 'Select Image', 'katerina' ); ?></button>
			</div>
		</div>

		<?php $slider_displacement_intensity = get_post_meta( $post->ID, 'slider_displacement_intensity', true ); ?>
		<div class="katerina-metabox-field katerina-metabox-field-input">
			<div class="katerina-metabox-label">
				<label for="slider_displacement_intensity"><strong><?php esc_html_e( 'Displacement Effect Intensity', 'katerina' ); ?></strong></label>
			</div>
			<div class="katerina-metabox-input">
				<input type="number" class="regular-text" id="slider_displacement_intensity" name="slider_displacement_intensity" value="<?php echo esc_attr( $slider_displacement_intensity ); ?>" min="0" max="100" step="5" placeholder="30">%
			</div>
		</div>

		<?php $slider_transition = get_post_meta( $post->ID, 'slider_transition', true ); ?>
		<div class="katerina-metabox-field katerina-metabox-field-input">
			<div class="katerina-metabox-label">
				<label for="slider_transition"><strong><?php esc_html_e( 'Slider Transition Duration', 'katerina' ); ?></strong></label>
			</div>
			<div class="katerina-metabox-input">
				<input type="number" class="regular-text" id="slider_transition" name="slider_transition" value="<?php echo esc_attr( $slider_transition ); ?>" min="100" max="3000" step="100" placeholder="1000">ms
			</div>
		</div>

		<?php
		$slider_automatic = get_post_meta( $post->ID, 'slider_automatic', true );
		$slider_automatic_speed = get_post_meta( $post->ID, 'slider_automatic_speed', true );
		$slider_automatic_initial_delay = get_post_meta( $post->ID, 'slider_automatic_initial_delay', true );
		$slider_hoverpause = get_post_meta( $post->ID, 'slider_hoverpause', true );
		?>
		<div class="katerina-metabox-field katerina-metabox-field-checkbox">
			<div class="katerina-metabox-label">
				<label for="slider_automatic"><strong><?php esc_html_e( 'Auto slide', 'katerina' ); ?></strong></label>
			</div>
			<div class="katerina-metabox-input">
				<label for="slider_automatic" class="selectit"><input type="checkbox" name="slider_automatic" id="slider_automatic" value="1"<?php checked( ! empty( $slider_automatic ) ); ?>></label>
				<div class="slider_automatic_details"<?php if ( empty( $slider_automatic ) ) : ?> style="display:none"<?php endif; ?>>
					<strong><?php esc_html_e( 'Speed:', 'katerina' ); ?></strong> <input type="number" class="regular-text" id="slider_automatic_speed" name="slider_automatic_speed" value="<?php echo esc_attr( $slider_automatic_speed ); ?>" min="0" max="20000" step="100" placeholder="8000">ms 
					<strong><?php esc_html_e( 'Initial delay:', 'katerina' ); ?></strong> <input type="number" class="regular-text" id="slider_automatic_initial_delay" name="slider_automatic_initial_delay" value="<?php echo esc_attr( $slider_automatic_initial_delay ); ?>" min="0" max="10000" step="100" placeholder="1500">ms 
					<label for="slider_hoverpause" class="selectit"><input type="checkbox" name="slider_hoverpause" id="slider_hoverpause" value="1"<?php checked( ! empty( $slider_hoverpause ) ); ?>> <?php esc_html_e( 'Pause while hovering over slider', 'katerina' ); ?></label>
				</div>
			</div>
		</div>

		<?php $slider_keyboardnav = get_post_meta( $post->ID, 'slider_keyboardnav', true ); ?>
		<div class="katerina-metabox-field katerina-metabox-field-checkbox">
			<div class="katerina-metabox-label">
				<label for="slider_keyboardnav"><strong><?php esc_html_e( 'Disable keyboard navigation', 'katerina' ); ?></strong></label>
			</div>
			<div class="katerina-metabox-input">
				<label for="slider_keyboardnav" class="selectit"><input type="checkbox" name="slider_keyboardnav" id="slider_keyboardnav" value="1"<?php checked( ! empty( $slider_keyboardnav ) ); ?>> <?php esc_html_e( 'Disable keyboard left/right navigation', 'katerina' ); ?></label>
			</div>
		</div>

		<?php $slider_touchnav = get_post_meta( $post->ID, 'slider_touchnav', true ); ?>
		<div class="katerina-metabox-field katerina-metabox-field-checkbox">
			<div class="katerina-metabox-label">
				<label for="slider_touchnav"><strong><?php esc_html_e( 'Disable touch navigation', 'katerina' ); ?></strong></label>
			</div>
			<div class="katerina-metabox-input">
				<label for="slider_touchnav" class="selectit"><input type="checkbox" name="slider_touchnav" id="slider_touchnav" value="1"<?php checked( ! empty( $slider_touchnav ) ); ?>> <?php esc_html_e( 'Disable touch swipe navigation', 'katerina' ); ?></label>
			</div>
		</div>

	</div>

	<?php $custom_featured_area_html = get_post_meta( $post->ID, 'custom_featured_area_html', true ); ?>
	<div class="katerina-metabox-field katerina-metabox-field-wysiwyg"<?php if ( empty( $featured_area_type ) || 'featured' === $featured_area_type || 'slider' === $featured_area_type ) : ?> style="display:none"<?php endif; ?>>
		<div class="katerina-metabox-input">
			<?php
			wp_editor( $custom_featured_area_html, 'custom_featured_area_html', array( 'textarea_rows' => 8 ) );
			?>
		</div>
	</div>

	<?php $featured_general_text = get_post_meta( $post->ID, 'featured_general_text', true ); ?>
	<div class="katerina-metabox-field katerina-metabox-field-wysiwyg"<?php if ( empty( $featured_area_type ) ) : ?> style="display:none"<?php endif; ?>>
			<div class="katerina-metabox-label">
				<label for="featured_general_text"><strong><?php esc_html_e( 'Contact Details', 'katerina' ); ?></strong></label>
			</div>
		<div class="katerina-metabox-input">
			<?php
			wp_editor( $featured_general_text, 'featured_general_text', array( 'textarea_rows' => 5 ) );
			?>
		</div>
	</div>

	<?php $featured_area_text = get_post_meta( $post->ID, 'featured_area_text', true ); ?>
	<div class="katerina-metabox-field katerina-metabox-field-wysiwyg"<?php if ( empty( $featured_area_type ) || 'slider' === $featured_area_type ) : ?> style="display:none"<?php endif; ?>>
			<div class="katerina-metabox-label">
				<label for="featured_area_text"><strong><?php esc_html_e( 'Featured Text', 'katerina' ); ?></strong></label>
			</div>
		<div class="katerina-metabox-input">
			<?php
			wp_editor( $featured_area_text, 'featured_area_text', array( 'textarea_rows' => 8 ) );
			?>
		</div>
	</div>

	<?php $featured_area_no_overlay = get_post_meta( $post->ID, 'featured_area_no_overlay', true ); ?>
	<div class="katerina-metabox-field katerina-metabox-field-checkbox"<?php if ( empty( $featured_area_type ) ) : ?> style="display:none"<?php endif; ?>>
		<div class="katerina-metabox-label">
			<label for="featured_area_no_overlay"><strong><?php esc_html_e( 'Featured Overlay', 'katerina' ); ?></strong></label>
		</div>
		<div class="katerina-metabox-input">
			<label for="featured_area_no_overlay" class="selectit"><input type="checkbox" name="featured_area_no_overlay" id="featured_area_no_overlay" value="1"<?php checked( ! empty( $featured_area_no_overlay ) ); ?>> <?php esc_html_e( 'Disable the overlay over the featured area', 'katerina' ); ?></label>
		</div>
	</div>

	<?php $featured_area_no_social = get_post_meta( $post->ID, 'featured_area_no_social', true ); ?>
	<div class="katerina-metabox-field katerina-metabox-field-checkbox"<?php if ( empty( $featured_area_type ) ) : ?> style="display:none"<?php endif; ?>>
		<div class="katerina-metabox-label">
			<label for="featured_area_no_social"><strong><?php esc_html_e( 'Featured Social Links', 'katerina' ); ?></strong></label>
		</div>
		<div class="katerina-metabox-input">
			<label for="featured_area_no_social" class="selectit"><input type="checkbox" name="featured_area_no_social" id="featured_area_no_social" value="1"<?php checked( ! empty( $featured_area_no_social ) ); ?>> <?php esc_html_e( 'Disable the social links from the featured area', 'katerina' ); ?></label>
		</div>
	</div>

	<?php $featured_area_no_scroll_content = get_post_meta( $post->ID, 'featured_area_no_scroll_content', true ); ?>
	<div class="katerina-metabox-field katerina-metabox-field-checkbox"<?php if ( empty( $featured_area_type ) ) : ?> style="display:none"<?php endif; ?>>
		<div class="katerina-metabox-label">
			<label for="featured_area_no_scroll_content"><strong><?php esc_html_e( 'Featured Scroll', 'katerina' ); ?></strong></label>
		</div>
		<div class="katerina-metabox-input">
			<label for="featured_area_no_scroll_content" class="selectit"><input type="checkbox" name="featured_area_no_scroll_content" id="featured_area_no_scroll_content" value="1"<?php checked( ! empty( $featured_area_no_scroll_content ) ); ?>> <?php esc_html_e( 'Disable the scroll to content link', 'katerina' ); ?></label>
		</div>
	</div>

	<?php $content_style = get_post_meta( $post->ID, 'content_style', true ); ?>
	<div class="katerina-metabox-field katerina-metabox-field-select">
		<div class="katerina-metabox-label">
			<label for="content_style"><strong><?php esc_html_e( 'Content Area', 'katerina' ); ?></strong></label>
		</div>
		<div class="katerina-metabox-input">
			<select name="content_style" id="content_style">
				<option value=""<?php if ( empty( $content_style ) ) : ?> selected="selected"<?php endif; ?>><?php esc_html_e( 'Default', 'katerina' ); ?></option>
				<option value="no-title"<?php if ( ! empty( $content_style ) && 'no-title' === $content_style ) : ?> selected="selected"<?php endif; ?>><?php esc_html_e( 'No Title', 'katerina' ); ?></option>
				<option value="full"<?php if ( ! empty( $content_style ) && 'full' === $content_style ) : ?> selected="selected"<?php endif; ?>><?php esc_html_e( 'Full Width With No Title', 'katerina' ); ?></option>
				<option value="hide"<?php if ( ! empty( $content_style ) && 'hide' === $content_style ) : ?> selected="selected"<?php endif; ?>><?php esc_html_e( 'Hide Content Area', 'katerina' ); ?></option>
			</select>
		</div>
	</div>

	<?php $title_tagline = get_post_meta( $post->ID, 'title_tagline', true ); ?>
	<div class="katerina-metabox-field katerina-metabox-field-wysiwyg"<?php if ( isset( $content_style ) && ! empty( $content_style ) ) : ?> style="display:none"<?php endif; ?>>
		<div class="katerina-metabox-label">
			<label for="title_tagline"><strong><?php esc_html_e( 'Title Tagline', 'katerina' ); ?></strong></label>
		</div>
		<div class="katerina-metabox-input">
			<?php
			wp_editor(
				$title_tagline,
				'title_tagline',
				array(
					'media_buttons' => false,
					'textarea_rows' => 1,
					'tinymce'       => false,
					'quicktags'     => array(
						'buttons' => 'strong,em,link,ins',
					),
				)
			);
			?>
			<p class="description"><?php esc_html_e( 'Optional text displayed under the title of the post/page.', 'katerina' ); ?></p>
		</div>
	</div>

	<?php if ( "page" !== $post->post_type ) : ?>
		<?php $no_featured_image = get_post_meta( $post->ID, 'no_featured_image', true ); ?>
		<div class="katerina-metabox-field katerina-metabox-field-checkbox">
			<div class="katerina-metabox-label">
				<label for="no_featured_image"><strong><?php esc_html_e( 'Featured Image', 'katerina' ); ?></strong></label>
			</div>
			<div class="katerina-metabox-input">
				<label for="no_featured_image" class="selectit"><input type="checkbox" name="no_featured_image" id="no_featured_image" value="1"<?php checked( ! empty( $no_featured_image ) ); ?>> <?php esc_html_e( "Don't display the featured image for this post (in single view).", 'katerina' ); ?></label>
			</div>
		</div>
	<?php endif; ?>

	<?php $page_sidebar = get_post_meta( $post->ID, 'page_sidebar', true ); ?>
	<div class="katerina-metabox-field katerina-metabox-field-select"<?php if ( isset( $content_style ) && 'hide' === $content_style ) : ?> style="display:none"<?php endif; ?>>
		<div class="katerina-metabox-label">
			<label for="page_sidebar"><strong><?php esc_html_e( 'Sidebar', 'katerina' ); ?></strong></label>
		</div>
		<div class="katerina-metabox-input">
			<select name="page_sidebar" id="page_sidebar">
				<option value=""<?php if ( empty( $page_sidebar ) ) : ?> selected="selected"<?php endif; ?>><?php esc_html_e( 'No Sidebar', 'katerina' ); ?></option>
				<option value="right"<?php if ( ! empty( $page_sidebar ) && 'right' === $page_sidebar ) : ?> selected="selected"<?php endif; ?>><?php esc_html_e( 'Sidebar - Right', 'katerina' ); ?></option>
				<option value="left"<?php if ( ! empty( $page_sidebar ) && 'left' === $page_sidebar ) : ?> selected="selected"<?php endif; ?>><?php esc_html_e( 'Sidebar - Left', 'katerina' ); ?></option>
			</select>
		</div>
	</div>

	<?php $no_footer = get_post_meta( $post->ID, 'no_footer', true ); ?>
	<div class="katerina-metabox-field katerina-metabox-field-checkbox">
		<div class="katerina-metabox-label">
			<label for="no_footer"><strong><?php esc_html_e( 'Footer Area', 'katerina' ); ?></strong></label>
		</div>
		<div class="katerina-metabox-input">
			<label for="no_footer" class="selectit"><input type="checkbox" name="no_footer" id="no_footer" value="1"<?php checked( ! empty( $no_footer ) ); ?>> <?php esc_html_e( 'Disable the footer area for this post.', 'katerina' ); ?></label>
		</div>
	</div>

	<?php
}

/**
 * Save fields for the meta options.
 */
function katerina_additional_meta_fields_save_post( $post_id ) {
	$metabox_id = 'katerina-additional-fields';

	// check if nonce validates.
	if ( ! ( isset( $_POST[ "nonce_{$metabox_id}" ] ) && wp_verify_nonce( sanitize_key( $_POST[ "nonce_{$metabox_id}" ] ), "save_{$metabox_id}" ) ) ) {
		return;
	}

	if ( isset( $_POST['page_category'] ) ) {
		$page_category = sanitize_text_field( wp_unslash( $_POST['page_category'] ) );
		if ( empty( $page_category ) ) {
			delete_post_meta( $post_id, 'page_category' );
		} else {
			update_post_meta( $post_id, 'page_category', $page_category );
		}
	}

	if ( isset( $_POST['title_tagline'] ) ) {
		$title_tagline = wp_unslash( $_POST['title_tagline'] );
		if ( empty( $title_tagline ) ) {
			delete_post_meta( $post_id, 'title_tagline' );
		} else {
			update_post_meta( $post_id, 'title_tagline', $title_tagline );
		}
	}

	if ( isset( $_POST['featured_area_type'] ) ) {
		$featured_area_type = sanitize_text_field( wp_unslash( $_POST['featured_area_type'] ) );
		if ( empty( $featured_area_type ) ) {
			delete_post_meta( $post_id, 'featured_area_type' );
		} else {
			update_post_meta( $post_id, 'featured_area_type', $featured_area_type );
		}
	}

	if ( isset( $_POST['custom_featured_area_html'] ) ) {
		$custom_featured_area_html = wp_unslash( $_POST['custom_featured_area_html'] );
		if ( empty( $custom_featured_area_html ) ) {
			delete_post_meta( $post_id, 'custom_featured_area_html' );
		} else {
			update_post_meta( $post_id, 'custom_featured_area_html', $custom_featured_area_html );
		}
	}

	if ( isset( $_POST['custom_featured_area'] ) ) {
		if ( isset( $_POST['featured_slider_type'] ) ) {
			$featured_slider_type   = $_POST['featured_slider_type'];
			$featured_slider_field1 = $_POST['featured_slider_field1'];
			$featured_slider_field2 = $_POST['featured_slider_field2'];
			$featured_slider_field3 = $_POST['featured_slider_field3'];
			$count_featured_slides  = count( $featured_slider_type );
			$new_value              = array();

			for ( $i = 0; $i < $count_featured_slides; $i++ ) {
				$new_value[ $i ]['type'] = $featured_slider_type[ $i ];
				switch ( $featured_slider_type[ $i ] ) {
					case 'image':
						if ( '' != $featured_slider_field1[ $i ] ) {
							$new_value[ $i ]['image'] = $featured_slider_field1[ $i ];
						}
						if ( '' != $featured_slider_field2[ $i ] ) {
							$new_value[ $i ]['caption'] = $featured_slider_field2[ $i ];
						}
						break;
					case 'video':
						if ( '' != $featured_slider_field1[ $i ] ) {
							$new_value[ $i ]['video'] = $featured_slider_field1[ $i ];
						}
						if ( '' != $featured_slider_field2[ $i ] ) {
							$new_value[ $i ]['cover'] = $featured_slider_field2[ $i ];
						}
						if ( '' != $featured_slider_field3[ $i ] ) {
							$new_value[ $i ]['caption'] = $featured_slider_field3[ $i ];
						}
						break;
				}
			}

			if ( 0 == count( $new_value ) ) {
				delete_post_meta( $post_id, 'custom_featured_area' );
			} else {
				update_post_meta( $post_id, 'custom_featured_area', $new_value );
			}
		} else {
			delete_post_meta( $post_id, 'custom_featured_area' );
		}
	}

	if ( isset( $_POST['slider_displacement'] ) ) {
		$slider_displacement = wp_unslash( $_POST['slider_displacement'] );
		if ( empty( $slider_displacement ) ) {
			delete_post_meta( $post_id, 'slider_displacement' );
		} else {
			update_post_meta( $post_id, 'slider_displacement', $slider_displacement );
		}
	}

	if ( isset( $_POST['slider_displacement_intensity'] ) ) {
		$slider_displacement_intensity = wp_unslash( $_POST['slider_displacement_intensity'] );
		if ( empty( $slider_displacement_intensity ) ) {
			delete_post_meta( $post_id, 'slider_displacement_intensity' );
		} else {
			update_post_meta( $post_id, 'slider_displacement_intensity', $slider_displacement_intensity );
		}
	}

	if ( isset( $_POST['slider_transition'] ) ) {
		$slider_transition = wp_unslash( $_POST['slider_transition'] );
		if ( empty( $slider_transition ) ) {
			delete_post_meta( $post_id, 'slider_transition' );
		} else {
			update_post_meta( $post_id, 'slider_transition', $slider_transition );
		}
	}

	if ( isset( $_POST['slider_automatic'] ) ) {
		$slider_automatic = sanitize_text_field( wp_unslash( $_POST['slider_automatic'] ) );
		$slider_automatic_speed = wp_unslash( $_POST['slider_automatic_speed'] );
		$slider_automatic_initial_delay = wp_unslash( $_POST['slider_automatic_initial_delay'] );
		$slider_hoverpause = sanitize_text_field( wp_unslash( $_POST['slider_hoverpause'] ) );
		if ( ! empty( $slider_automatic ) ) {
			update_post_meta( $post_id, 'slider_automatic', true );
			if ( '' === $slider_automatic_speed ) {
				delete_post_meta( $post_id, 'slider_automatic_speed' );
			} else {
				update_post_meta( $post_id, 'slider_automatic_speed', $slider_automatic_speed );
			}
			if ( '' === $slider_automatic_initial_delay ) {
				delete_post_meta( $post_id, 'slider_automatic_initial_delay' );
			} else {
				update_post_meta( $post_id, 'slider_automatic_initial_delay', $slider_automatic_initial_delay );
			}
			if ( ! empty( $slider_hoverpause ) ) {
				update_post_meta( $post_id, 'slider_hoverpause', true );
			} else {
				delete_post_meta( $post_id, 'slider_hoverpause' );
			}
		} else {
			delete_post_meta( $post_id, 'slider_automatic' );
			delete_post_meta( $post_id, 'slider_automatic_speed' );
			delete_post_meta( $post_id, 'slider_automatic_initial_delay' );
			delete_post_meta( $post_id, 'slider_hoverpause' );
		}
	} else {
		delete_post_meta( $post_id, 'slider_automatic' );
		delete_post_meta( $post_id, 'slider_automatic_speed' );
		delete_post_meta( $post_id, 'slider_automatic_initial_delay' );
		delete_post_meta( $post_id, 'slider_hoverpause' );
	}

	if ( isset( $_POST['slider_keyboardnav'] ) ) {
		$slider_keyboardnav = sanitize_text_field( wp_unslash( $_POST['slider_keyboardnav'] ) );
		if ( ! empty( $slider_keyboardnav ) ) {
			update_post_meta( $post_id, 'slider_keyboardnav', true );
		} else {
			delete_post_meta( $post_id, 'slider_keyboardnav' );
		}
	} else {
		delete_post_meta( $post_id, 'slider_keyboardnav' );
	}

	if ( isset( $_POST['slider_touchnav'] ) ) {
		$slider_touchnav = sanitize_text_field( wp_unslash( $_POST['slider_touchnav'] ) );
		if ( ! empty( $slider_touchnav ) ) {
			update_post_meta( $post_id, 'slider_touchnav', true );
		} else {
			delete_post_meta( $post_id, 'slider_touchnav' );
		}
	} else {
		delete_post_meta( $post_id, 'slider_touchnav' );
	}

	if ( isset( $_POST['featured_general_text'] ) ) {
		$featured_general_text = wp_unslash( $_POST['featured_general_text'] );
		if ( empty( $featured_general_text ) ) {
			delete_post_meta( $post_id, 'featured_general_text' );
		} else {
			update_post_meta( $post_id, 'featured_general_text', $featured_general_text );
		}
	}

	if ( isset( $_POST['featured_area_text'] ) ) {
		$featured_area_text = wp_unslash( $_POST['featured_area_text'] );
		if ( empty( $featured_area_text ) ) {
			delete_post_meta( $post_id, 'featured_area_text' );
		} else {
			update_post_meta( $post_id, 'featured_area_text', $featured_area_text );
		}
	}

	if ( isset( $_POST['featured_area_no_overlay'] ) ) {
		$featured_area_no_overlay = sanitize_text_field( wp_unslash( $_POST['featured_area_no_overlay'] ) );
		if ( ! empty( $featured_area_no_overlay ) ) {
			update_post_meta( $post_id, 'featured_area_no_overlay', true );
		} else {
			delete_post_meta( $post_id, 'featured_area_no_overlay' );
		}
	} else {
		delete_post_meta( $post_id, 'featured_area_no_overlay' );
	}

	if ( isset( $_POST['featured_area_no_social'] ) ) {
		$featured_area_no_social = sanitize_text_field( wp_unslash( $_POST['featured_area_no_social'] ) );
		if ( ! empty( $featured_area_no_social ) ) {
			update_post_meta( $post_id, 'featured_area_no_social', true );
		} else {
			delete_post_meta( $post_id, 'featured_area_no_social' );
		}
	} else {
		delete_post_meta( $post_id, 'featured_area_no_social' );
	}

	if ( isset( $_POST['featured_area_no_scroll_content'] ) ) {
		$featured_area_no_scroll_content = sanitize_text_field( wp_unslash( $_POST['featured_area_no_scroll_content'] ) );
		if ( ! empty( $featured_area_no_scroll_content ) ) {
			update_post_meta( $post_id, 'featured_area_no_scroll_content', true );
		} else {
			delete_post_meta( $post_id, 'featured_area_no_scroll_content' );
		}
	} else {
		delete_post_meta( $post_id, 'featured_area_no_scroll_content' );
	}

	if ( isset( $_POST['no_featured_image'] ) ) {
		$no_featured_image = sanitize_text_field( wp_unslash( $_POST['no_featured_image'] ) );
		if ( ! empty( $no_featured_image ) ) {
			update_post_meta( $post_id, 'no_featured_image', true );
		} else {
			delete_post_meta( $post_id, 'no_featured_image' );
		}
	} else {
		delete_post_meta( $post_id, 'no_featured_image' );
	}

	if ( isset( $_POST['page_sidebar'] ) ) {
		$page_sidebar = sanitize_text_field( wp_unslash( $_POST['page_sidebar'] ) );
		if ( empty( $page_sidebar ) ) {
			delete_post_meta( $post_id, 'page_sidebar' );
		} else {
			update_post_meta( $post_id, 'page_sidebar', $page_sidebar );
		}
	}

	if ( isset( $_POST['content_style'] ) ) {
		$content_style = sanitize_text_field( wp_unslash( $_POST['content_style'] ) );
		if ( empty( $content_style ) ) {
			delete_post_meta( $post_id, 'content_style' );
		} else {
			update_post_meta( $post_id, 'content_style', $content_style );
		}
	}

	if ( isset( $_POST['no_footer'] ) ) {
		$no_footer = sanitize_text_field( wp_unslash( $_POST['no_footer'] ) );
		if ( ! empty( $no_footer ) ) {
			update_post_meta( $post_id, 'no_footer', true );
		} else {
			delete_post_meta( $post_id, 'no_footer' );
		}
	} else {
		delete_post_meta( $post_id, 'no_footer' );
	}
}
add_action( 'save_post', 'katerina_additional_meta_fields_save_post' );
