<?php
/**
 * Setup main theme functions and hooks.
 */

/**
 * Add some useful classes to the body DOM element.
 */
function katerina_body_classes( $classes ) {

	// Get current post id.
	global $wp_query;
	if ( $wp_query->is_singular ) {
		$post_id = $wp_query->queried_object_id;
	} elseif ( is_home() && ! is_front_page() ) {
		$post_id = get_option( 'page_for_posts' );
	} elseif ( class_exists( 'WooCommerce' ) && is_shop() ) {
		$post_id = get_option( 'woocommerce_shop_page_id' );
	}

	if ( isset( $post_id ) ) {
		$featured_area_type = get_post_meta( $post_id, 'featured_area_type', true );
		if ( ! empty( $featured_area_type ) ) {
			$classes[] = 'has-featured';
		}

		$content_style = get_post_meta( $post_id, 'content_style', true );
		if ( ! empty( $content_style ) ) {
			$classes[] = 'content-style-' . esc_attr( $content_style );
		}

		$no_footer_override = get_post_meta( $post_id, 'no_footer', true );
		if ( $no_footer_override ) {
			$classes[] = 'no-footer';
		}
	}
	if ( is_404() ) {
		$classes[] = 'has-featured';
	}

	if ( ! has_custom_logo() ) {
		$classes[] = 'no-custom-logo';
	}

	if ( true == get_theme_mod( 'primary_menu_sticky', false ) ) {
		$classes[] = 'navbar-sticky';
	}

	if ( get_theme_mod( 'page_animation', false ) ) {
		$classes[] = 'page-animation';
	}

	if ( true == get_theme_mod( 'parallax_effect', false ) ) {
		$classes[] = 'theme-parallax';
	}

	if ( get_theme_mod( 'page_border', false ) ) {
		$classes[] = 'page-border';
	} else {
		$classes[] = 'no-page-border';
	}
	if ( ! is_active_sidebar( 'footer' ) ) {
		$classes[] = 'no-footer';
	}

	if ( katerina_is_sidebar_active() || ( function_exists( 'katerina_is_shop_sidebar_active' ) && katerina_is_shop_sidebar_active() ) ) {
		$classes[] = 'has-sidebar';

		if ( isset( $post_id ) ) {
			$page_sidebar = get_post_meta( $post_id, 'page_sidebar', true );
			if ( ! empty( $page_sidebar ) ) {
				$classes[] = 'sidebar-' . esc_attr( $page_sidebar );
			}
		}
	}

	if ( class_exists( 'WooCommerce' ) && is_shop() ) {
		if ( isset( $post_id ) ) {
			$page_sidebar = get_post_meta( $post_id, 'page_sidebar', true );
			// if user preferes no sidebar, then remove the class
			if ( empty( $page_sidebar ) && ( false !== ( $key = array_search( 'has-sidebar', $classes ) ) ) ) {
				unset( $classes[ $key ] );
			}
		}
	}

	if ( is_customize_preview() ) {
		$classes[] = 'customize-preview';
	}

	return $classes;
}
add_filter( 'body_class', 'katerina_body_classes' );

/**
 * Get information about the logo, add dark mode support.
 */
function katerina_get_custom_logo( $html ) {

	$logo_id = get_theme_mod( 'custom_logo' );
	if ( ! $logo_id ) {
		return $html;
	}

	$logo = wp_get_attachment_image_src( $logo_id, 'full' );

	if ( $logo ) {
		$logo_src    = esc_attr( $logo[0] );
		$logo_width  = esc_attr( $logo[1] );
		$logo_height = esc_attr( $logo[2] );

		// If logo has retina sufix at the end, reduce the width/height by half.
		if ( false != stripos( $logo_src, '@2X' ) ) {
			$logo_width  = floor( $logo_width / 2 );
			$logo_height = floor( $logo_height / 2 );

			$search = array(
				'/width=\"\d+\"/iU',
				'/height=\"\d+\"/iU',
			);

			$replace = array(
				"width=\"{$logo_width}\"",
				"height=\"{$logo_height}\"",
			);

			// Add a style attribute with the height, or append the height to the style attribute if the style attribute already exists.
			if ( false == strpos( $html, ' style=' ) ) {
				$search[]  = '/(src=)/';
				$replace[] = "style=\"height: {$logo_height}px;\" src=";
			} else {
				$search[]  = '/(style="[^"]*)/';
				$replace[] = "$1 height: {$logo_height}px;";
			}
			$html = preg_replace( $search, $replace, $html );
		}

		if ( 0 !== get_theme_mod( 'allow_alt_colors', 0 ) ) {
			$custom_logo_alt_id = get_theme_mod( 'custom_logo_alt', false );
			if ( $custom_logo_alt_id ) {
				$custom_logo_alt        = wp_get_attachment_image_src( $custom_logo_alt_id, 'full' );
				$custom_logo_alt_src    = esc_attr( $custom_logo_alt[0] );
				$custom_logo_alt_width  = esc_attr( $custom_logo_alt[1] );
				$custom_logo_alt_height = esc_attr( $custom_logo_alt[2] );
				if ( false != stripos( $custom_logo_alt_src, '@2X' ) ) {
					$custom_logo_alt_width  = floor( $custom_logo_alt_width / 2 );
					$custom_logo_alt_height = floor( $custom_logo_alt_height / 2 );
				}
				$custom_logo_alt_html   = '<img src="$1" width="$2" height="$3" class="custom-logo alt-version" alt="$4" />';
				$custom_logo_alt_html = str_replace(
					array(
						'$2',
						'$3',
						'$4',
					),
					array(
						$custom_logo_alt_width,
						$custom_logo_alt_height,
						get_bloginfo( 'name', 'display' ),
					),
					$custom_logo_alt_html
				);
				$custom_logo_alt_html = str_replace( '$1', esc_url( $custom_logo_alt_src ), $custom_logo_alt_html );
				$html             = str_replace( '</a>', $custom_logo_alt_html . '</a>', $html );
			}
		}
	}

	return $html;
}
add_filter( 'get_custom_logo', 'katerina_get_custom_logo' );

if ( ! function_exists( 'katerina_is_sidebar_active' ) ) {
	function katerina_is_sidebar_active() {
		global $wp_query;
		if ( $wp_query->is_singular ) {
			$post_id = $wp_query->queried_object_id;
		} elseif ( is_home() && ! is_front_page() ) {
			$post_id = get_option( 'page_for_posts' );
		}

		if ( isset( $post_id ) ) {
			$page_sidebar = get_post_meta( $post_id, 'page_sidebar', true );
			if ( is_active_sidebar( 'page-sidebar' ) && ! empty( $page_sidebar ) ) {
				return true;
			}
		}

		return is_active_sidebar( 'page-sidebar' ) && ( is_home() || is_archive() || is_search() );
	}
}

if ( ! function_exists( 'katerina_posted_on' ) ) {
	/**
	 * Prints the current post-date/time of a post.
	 */
	function katerina_posted_on() {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
		if ( get_the_time( 'U' ) != get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
		}

		$time_string = sprintf(
			$time_string,
			get_the_date( DATE_W3C ),
			get_the_date(),
			get_the_modified_date( DATE_W3C ),
			get_the_modified_date()
		);

		// try to override the permalink, if this is a 'link' post type
		$post_link = get_permalink();
		if ( 'link' == get_post_format() ) {
			$content = get_the_content();
			if ( preg_match( "/<a\s[^>]*href=([\"\']??)([^\\1 >]*?)\\1[^>]*>(.*)<\/a>/siU", $content, $matches ) && isset( $matches[2] ) ) {
				$post_link = $matches[2];
			}
		}

		echo '<span class="screen-reader-text">' .
			esc_html__( 'Posted on', 'katerina' ) .
			'</span> ' .
			'<a href="' . esc_url( $post_link ) . '" rel="bookmark">' . katerina_theme_svg( 'calendar' ) . $time_string . '</a>';
	}
}


if ( ! function_exists( 'katerina_estimated_reading_time' ) ) {
	/**
	 * Estimate time required to read the article.
	 */
	function katerina_estimated_reading_time() {
		$post    = get_post();
		$wpm     = 300;
		$words   = str_word_count( strip_tags( $post->post_content ) );
		$minutes = ceil( $words / $wpm );

		$estimated_time = '';
		if ( $minutes < 1 ) {
			$estimated_time .= esc_html__( '< 1', 'katerina' );
		} else {
			$estimated_time .= $minutes;
		}
		$estimated_time .= ' ' . _n( 'minute read', 'minutes read', $minutes, 'katerina' );

		return $estimated_time;
	}
}

/**
 * Returns true if a blog has more than 1 category.
 */
function katerina_categorized_blog() {
	// Allow viewing case of 0 or 1 categories in post preview.
	if ( is_preview() ) {
		return true;
	}

	$category_count = get_transient( 'katerina_categories' );

	if ( false == $category_count ) {
		// Create an array of all the categories that are attached to posts.
		$categories = get_categories(
			array(
				'fields'     => 'ids',
				'hide_empty' => 1,
				// We only need to know if there is more than one category.
				'number'     => 2,
			)
		);

		// Count the number of categories that are attached to the posts.
		$category_count = count( $categories );
		set_transient( 'katerina_categories', $category_count );
	}

	return $category_count > 1;
}

/**
 * Flush out the transients used in katerina_categorized_blog.
 */
function katerina_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	delete_transient( 'katerina_categories' );
}
add_action( 'edit_category', 'katerina_category_transient_flusher' );
add_action( 'save_post', 'katerina_category_transient_flusher' );

/**
 * Add toggle buttons used in the mobile display of the theme top menu.
 */
function katerina_nav_menu_customize_items( $items, $args ) {
	if ( 'primary' === $args->theme_location ) {
		return preg_replace(
			array(
				'/>(\s|\n|\r)+</',
				'~</a><ul class="sub-menu">~',
			),
			array(
				'><',
				katerina_get_svg( 'chevron-down' ) . '</a><ul class="sub-menu">',
			),
			$items
		);
	}
	return $items;
}
add_filter( 'wp_nav_menu_items', 'katerina_nav_menu_customize_items', 15, 2 );

/**
 * Add search and color scheme buttons in the theme top menu.
 */
function katerina_nav_menu_items_add_custom( $items, $args ) {
	if ( ( has_nav_menu( 'primary' ) && 'primary' === $args->theme_location ) ) {
		ob_start();
		get_template_part( 'template-parts/navigation/navigation-primary', 'color-scheme' );
		$color_scheme_menu_item = ob_get_contents();
		ob_end_clean();
		$items = $items . $color_scheme_menu_item;

		ob_start();
		get_template_part( 'template-parts/navigation/navigation-primary', 'search' );
		$search_menu_item = ob_get_contents();
		ob_end_clean();
		$items = $items . $search_menu_item;
	}
	return $items;
}
add_filter( 'wp_nav_menu_items', 'katerina_nav_menu_items_add_custom', 12, 2 );

/**
 * Add theme html attributes, like no-js or color scheme.
 */
function katerina_html_attributes( $output ) {
	$output .= ' class="no-js' . ( is_customize_preview() ? ' customizing' : '' ) . '"';
	if ( 0 !== get_theme_mod( 'allow_alt_colors', 0 ) ) {
		if ( 0 !== get_theme_mod( 'alt_colors_by_default', 0 ) ) {
			$output .= ' data-scheme="alt"';
		}
	}
	return $output;
}
add_filter( 'language_attributes', 'katerina_html_attributes', 15, 2 );

/**
 * Check if Block Editor is active.
 * Must only be used after plugins_loaded action is fired.
 */
function katerina_has_block_editor() {
	// Gutenberg plugin is installed and activated.
	$gutenberg = ! ( false === has_filter( 'replace_editor', 'gutenberg_init' ) );

	// Block editor since 5.0.
	$block_editor = version_compare( $GLOBALS['wp_version'], '5.0-beta', '>' );

	if ( ! $gutenberg && ! $block_editor ) {
		return false;
	}

	return true;
}

/**
 * Modifies tag cloud widget arguments to have all tags in the widget same font size.
 */
function katerina_widget_tag_cloud_args( $args ) {
	$args['smallest'] = 1;
	$args['largest']  = 1;
	$args['unit']     = 'em';
	return $args;
}
add_filter( 'widget_tag_cloud_args', 'katerina_widget_tag_cloud_args' );

if ( ! function_exists( 'katerina_pagination_links' ) ) {
	/**
	 * Display pagination links.
	 */
	function katerina_pagination_links() {
		global $wp_query;
		$max = $wp_query->max_num_pages;
		if ( $max > 1 ) {
			$arg                       = array();
			$big_no                    = 9999999;
			$arg['base']               = str_replace( $big_no, '%#%', esc_url( get_pagenum_link( $big_no ) ) );
			$arg['total']              = $max;
			$arg['current']            = max( 1, get_query_var( 'paged' ) );
			$arg['before_page_number'] = '<span class="screen-reader-text">' . esc_html__( 'Page', 'katerina' ) . ' </span>';
			$arg['prev_text']          = katerina_get_svg( 'arrow-' . ( is_rtl() ? 'right' : 'left' ) ) . '<span class="screen-reader-text">' . esc_html__( 'Previous Page', 'katerina' ) . ' </span>';
			$arg['next_text']          = '<span class="screen-reader-text">' . esc_html__( 'Next Page', 'katerina' ) . ' </span>' . katerina_get_svg( 'arrow-' . ( is_rtl() ? 'left' : 'right' ) );
			echo '<div class="pagination"><h2 class="screen-reader-text">' . esc_html__( 'Posts navigation', 'katerina' ) . '</h2>' . paginate_links( $arg ) . '</div>';
		}
	}
}

/**
 * Add a 'Read more' link to the excerpt
 */
function katerina_excerpt_content( $excerpt ) {
	if ( is_admin() ) {
		return $excerpt;
	}

	$post_link = get_permalink();
	if ( 'link' === get_post_format() ) {
		$content = get_the_content();
		if ( preg_match( "/<a\s[^>]*href=([\"\']??)([^\\1 >]*?)\\1[^>]*>(.*)<\/a>/siU", $content, $matches ) ) {
			if ( isset( $matches[2] ) ) {
				$post_link = $matches[2];
			}
		}
	}

	$link = sprintf(
		'<a href="%1$s" class="read-more">%2$s</a>',
		esc_url( $post_link ),
		katerina_listing_read_more_string() . katerina_get_svg( 'arrow-right-long' )
	);
	return $excerpt . $link;
}
add_filter( 'the_excerpt', 'katerina_excerpt_content' );

if ( ! function_exists( 'katerina_listing_read_more_string' ) ) {
	/**
	 * The string used for read more links (depending on the post type).
	 */
	function katerina_listing_read_more_string() {
		$read_more = '';
		switch ( get_post_type() ) {
			case 'page':
				$read_more = esc_html__( 'View page', 'katerina' );
				break;
			
			case 'product':
				$read_more = esc_html__( 'View product', 'katerina' );
				break;
			
			default:
				$read_more = esc_html__( 'Continue reading', 'katerina' );
				break;
		}

		return $read_more;
	}
}

/**
 * Maximum no. of words in the excerpt
 */
function katerina_excerpt_length( $length ) {
	if ( 'columns' === get_theme_mod( 'listing_style', false ) ) {
		return 25;
	}

	return 40;
}
add_filter( 'excerpt_length', 'katerina_excerpt_length' );

if ( ! function_exists( 'katerina_comments_callback' ) ) {
	/**
	 * Theme comment item callback.
	 */
	function katerina_comments_callback( $comment, $args, $depth ) {
		switch ( $comment->comment_type ) {
			default: // Proceed with normal comments.
				global $post;
				?>
				<li <?php comment_class(); ?> id="comment-<?php comment_ID(); ?>">
					<article class="comment-body">
						<?php if ( get_option( 'show_avatars', true ) ) : ?>
						<div class="comment-author-avatar">
							<?php echo get_avatar( $comment, 100 ); ?>
						</div>
					<?php endif; ?>
						<div class="comment-content-wrapper">
							<footer class="comment-meta">
								<div class="comment-author">
									<h6><?php echo get_comment_author_link( $comment->comment_ID ); ?></h6>
								</div>
								<div class="comment-date">
									<a href="<?php echo esc_url( get_comment_link( $comment->comment_ID ) ); ?>">
									<?php
									/* translators: 1: date, 2: time */
									printf( esc_html__( '%1$s at %2$s', 'katerina' ), wp_kses_post( get_comment_date() ), wp_kses_post( get_comment_time() ) );
									?>
									</a>
								</div>
							</footer>
							<div class="comment-content">
								<?php comment_text(); ?>
							</div>
							<div class="reply">
							<?php
							edit_comment_link( esc_html__( 'Edit', 'katerina' ) );
							comment_reply_link(
								array_merge(
									$args,
									array(
										'reply_text' => esc_html__( 'Reply', 'katerina' ),
										'depth'      => $depth,
										'max_depth'  => $args['max_depth'],
									)
								)
							);
							?>
							</div>
						</div>
					</article>
				<?php
				break;
		} // End switch().
	}
}

// Add theme wrapper to the entire page
function katerina_header_add_wrapper() {
	?>
	<div class="main-content-wrapper">
	<?php
}
function katerina_header_close_wrapper() {
	?>
	</div>
	<?php
}
add_action( 'katerina_header_before', 'katerina_header_add_wrapper' );
add_action( 'katerina_footer_after', 'katerina_header_close_wrapper' );

function katerina_gallery_block_render( $attributes, $content ) {
	$args = shortcode_atts(
		array(
			'align'            => '',
			'layout'           => 'dashboard',
			'grow_last'        => false,
			'filters'          => false,
			'filter_style'     => 'opacity',
			'switch_view'      => false,
			'post_type'        => 'post',
			'cat'              => -1,
			'order'            => 'DESC',
			'orderby'          => 'menu_order date',
			'aspect_ratio'     => 0,
			'caption'          => true,
			'caption_style'    => 'overlay-minimal',
			'caption_position' => 'top',
			'caption_theme'    => 'normal'
		),
		$attributes,
		'katerina-gallery'
	);

	$classes = '';
	$classes_extra = '';
	switch ( $args['layout'] ) {
		case 'grid':
			$classes .= ' style-dashboard style-grid fit-cover';
			if ( true !== $args['switch_view'] && 0 === $args['aspect_ratio'] ) {
				$args['aspect_ratio'] = 1;
			}
			break;

		case 'dashboard':
			$classes .= ' style-dashboard';
			if ( $args['grow_last'] ) {
				$classes .= ' grow-last-line';
			}
			break;

		case 'stream':
			$classes .= ' style-stream';
			break;
	}
	$classes_extra .= ! empty( $args['align'] ) ? ' align' . $args['align'] : '';
	$classes_extra .= ( 'hide' === $args['filter_style'] ) ? ' hide-filtered' : '';
	$classes_extra .= ( true === $args['switch_view'] ) ? ' show-type-switch' : '';
	$classes_extra .= ( true !== $args['filters'] ) ? ' no-filters' : '';
	$classes .= $classes_extra;
	$classes .= apply_filters( 'katerina_gallery_additional_classes', '', $attributes );

	$result = '<div class="katerina-gallery' . esc_attr( $classes ) . '">';

	if ( true === $args['switch_view'] ) {
		$result .= '<div class="output-type">';
		$result .= '<a href="#"' . ( 'stream' === $args['layout'] ? ' class="is-active"' : '' ) . ' data-type="style-stream' . $classes_extra . '" title="' . esc_html__( 'Stream view', 'katerina' ) . '">' . katerina_get_svg( 'view-stream' ) . '</a>';
		$result .= '<a href="#"' . ( 'grid' === $args['layout'] ? ' class="is-active"' : '' ) . ' data-type="style-dashboard style-grid fit-cover' . $classes_extra . '" title="' . esc_html__( 'Grid view', 'katerina' ) . '">' . katerina_get_svg( 'view-grid' ) . '</a>';
		$result .= '<a href="#"' . ( 'dashboard' === $args['layout'] ? ' class="is-active"' : '' ) . ' data-type="style-dashboard' . $classes_extra . ( 'dashboard' === $args['layout'] && $args['grow_last'] ? ' grow-last-line' : '' ) . '" title="' . esc_html__( 'Dashboard view', 'katerina' ) . '">' . katerina_get_svg( 'view-dashboard' ) . '</a>';
		$result .= '</div>';
	}

	$result_output = '<div class="katerina-gallery-output parallax-hover-children">';

	$katerina_query_args = array(
		'post_status'    => 'publish',
		'post_type'      => $args['post_type'],
		'order'          => $args['order'],
		'orderby'        => $args['orderby'],
		'posts_per_page' => -1, // used ONLY in this custom query
	);
	if ( $args['cat'] > 0 ) {
		$katerina_query_args['cat'] = $args['cat'];
	}
	query_posts( $katerina_query_args );
	$no_gallery_items = 0;
	while ( have_posts() ) {
		the_post();
		$no_gallery_items++;
		$post_thumbnail = get_the_post_thumbnail( get_the_ID(), 'large' );
		$style = '';
		if ( $post_thumbnail ) {
			$ratio = $args['aspect_ratio'];
			switch ( $ratio ) {
				case 0:
					preg_match( '/width="(.*?)"/', $post_thumbnail, $matches_width );
					preg_match( '/height="(.*?)"/', $post_thumbnail, $matches_height );
					if ( isset( $matches_width[1] ) && isset( $matches_height[1] ) ) {
						$ratio = $matches_width[1] / $matches_height[1];
					}
					// intentional fall-through
				default:
					if ( 1 != $ratio ) {
						$style = ' style="--ar:' . esc_attr( round( $ratio, 6 ) ) . '"';
					}
					break;
			}
		}
		$filters = '';
		if ( true === $args['filters'] && $args['cat'] > 0 ) {
			$categories = get_the_category();
			foreach ( $categories as $category ) {
				if ( $category->parent === $args['cat'] ) {
					$filters .= $category->slug . ' ';
				}
			}
			if ( $filters ) {
				$filters = ' data-filters="' . rtrim( $filters ) . '"';
			}
		}
		$result_output .= '<div class="katerina-gallery-entry"' . $filters . $style . '><a href="' . esc_url( get_the_permalink() ) . '">' . $post_thumbnail . '</a>';
		if ( true === $args['caption'] ) {
			$result_output .= '<span class="gallery-entry-description style-' . esc_attr( $args['caption_style'] ) . ' position-' . esc_attr( $args['caption_position'] ) . ( $args['caption_theme'] && 'inverted' === $args['caption_theme'] ? ' invert-colors' : '' ) . '">';
			$result_output .= '<strong>' . get_the_title() . '</strong>';
			if ( false === strpos( $args['caption_style'], 'minimal' ) ) {
				$result_output .= '<span>' . get_the_excerpt() . '</span>';
			}
			if ( false === strpos( $args['caption_style'], 'panel' ) ) {
				$result_output .= '<em>' . katerina_get_svg( 'arrow-right-long' ) . '</em>';
			} else if ( false === strpos( $args['caption_style'], 'minimal' ) ) {
				$result_output .= '<em>' . katerina_get_svg( 'plus' ) . '</em>';
			}
			$result_output .= '</span>';
		}
		$result_output .= '</div>';
	}
	$result_output .= '</div>';
	wp_reset_query();

	if ( true === $args['filters'] && $args['cat'] > 0 ) {
		$filters         = '';
		$parent_category = get_category( $args['cat'] );
		$sub_categories  = get_categories(
			array(
				'orderby'    => 'name',
				'order'      => 'ASC',
				'hide_empty' => true,
				'parent'     => $args['cat'],
			)
		);
		if ( count( $sub_categories ) > 0 ) {
			$result .= '<div class="output-filter"><ul>';
			$result .= '<li class="filter-all"><a href="#" class="is-active" data-filters="*">' . esc_html__( 'All', 'katerina' ) . ' <span class="count">' . $no_gallery_items . '</span></a></li>';
			foreach ( $sub_categories as $category ) {
				$result .= '<li><a href="#" data-filters="' . esc_attr( $category->slug ) . '">' . $category->name . ' <span class="count">' . $category->category_count . '</span></a></li>';
			}
			$result .= '</ul></div>';
		}
	}

	$result .= $result_output;

	$result .= '</div>';

	wp_enqueue_style( 'katerina-portfolio-gallery', get_template_directory_uri() . '/assets/css/portfolio-gallery.css', array( 'katerina' ), wp_get_theme()->get( 'Version' ) );

	return $result;
}
function katerina_gallery_callback() {
	return 'katerina_gallery_block_render';
}
add_filter( 'katerina_helper_gallery_render_callback', 'katerina_gallery_callback', 12 );

// Based on a Customizer setting, exclude a specific category from the Latest Posts (to hide project posts for example)
function katerina_exclude_category_home( $query ) {
	$exclude_from_blog = get_theme_mod( 'exclude_from_blog', false );
	if ( $exclude_from_blog && ! is_admin() && $query->is_main_query() && $query->is_home ) {
		$query->set( 'cat', '-' . $exclude_from_blog );
	}
	return $query;
}
add_filter( 'pre_get_posts', 'katerina_exclude_category_home' );

// Setup everything after the demo data import process.
function katerina_demo_data_finish_import() {
	// set menu locations.
	$primary_menu = get_term_by( 'name', 'Primary', 'nav_menu' );
	$social_menu  = get_term_by( 'name', 'Social', 'nav_menu' );
	if ( $primary_menu && $social_menu ) {
		set_theme_mod(
			'nav_menu_locations',
			array(
				'primary' => $primary_menu->term_id,
				'social'  => $social_menu->term_id,
			)
		);
	}

	// set homepage as a static page.
	$pages = get_pages();
	foreach ( $pages as $page ) {
		if ( '360° Panorama' === $page->post_title ) {
			update_option( 'show_on_front', 'page' );
			update_option( 'page_on_front', $page->ID );

			// update panorama shortcode image to the local version
			$featured_area_custom = get_post_meta( $page->ID, 'custom_featured_area_html', true );
			$new_shortcode_image_path = wp_get_attachment_image_url( 274, "full" );
			$featured_area_custom = str_replace( "https://liviucerchez.com/katerina/wp-content/uploads/sites/27/2022/09/forest-waterfall-seaside-bay-view.jpg", $new_shortcode_image_path, $featured_area_custom );
			update_post_meta( $page->ID, 'custom_featured_area_html', $featured_area_custom );
		}
		if ( 'Blog' === $page->post_title ) {
			update_option( 'page_for_posts', $page->ID );
		}
	}
}
add_action( 'theme_demo_data_finish_import', 'katerina_demo_data_finish_import' );

// Set demo data directory.
function katerina_demo_data_dir_path() {
	return dirname( __FILE__ ) . DIRECTORY_SEPARATOR . 'demo' . DIRECTORY_SEPARATOR;
}
add_filter( 'theme_demo_data_dir_path', 'katerina_demo_data_dir_path', 10 );

if ( is_admin() ) {

	// Add theme options to posts (as meta box options).
	require get_parent_theme_file_path( '/inc/meta-options.php' );

	/**
	 * Clear existent widgets during the import process.
	 */
	function katerina_import_widget_data( $data ) {
		update_option( 'sidebars_widgets', null );
		return $data;
	}
	add_action( 'katerina_theme_import_widget_data', 'katerina_import_widget_data' );

	/**
	 * Suggest plugins with the TGM Plugin Activation class.
	 */
	if ( file_exists( get_parent_theme_file_path( 'inc/plugins/class-tgm-plugin-activation.php' ) ) ) {
		include_once get_parent_theme_file_path( 'inc/plugins/class-tgm-plugin-activation.php' );

		/**
		 * Register theme required/recommanded plugins.
		 */
		function katerina_register_required_plugins() {
			$plugins = array(
				array(
					'name'        => 'Katerina Helper',
					'slug'        => 'katerina-helper',
					'source'      => get_template_directory() . '/inc/plugins/katerina-helper.zip',
					'version'     => '1.0',
					'required'    => false,
					'has_notices' => true,
				),
				array(
					'name'        => 'Contact Form 7',
					'slug'        => 'contact-form-7',
					'has_notices' => false,
				),
				array(
					'name'        => '360&deg; Panoramic Viewer',
					'slug'        => 'panorama360',
					'source'      => get_template_directory() . '/inc/plugins/panorama360.zip',
					'version'     => '3.0.4',
					'has_notices' => false,
				),
			);
			tgmpa( $plugins );
		}
		add_action( 'tgmpa_register', 'katerina_register_required_plugins' );
	}
}
