<?php
/*
 * Provide WooCommerce integration with the theme.
 */

/**
 * Declare theme compatibility with the plugin.
 */
function katerina_woo_support() {
	add_theme_support(
		'woocommerce',
		array(
			'product_grid' => array(
				'default_rows'    => 6,
				'min_rows'        => 2,
				'max_rows'        => 20,
				'default_columns' => 3,
				'min_columns'     => 2,
				'max_columns'     => 3,
			),
		)
	);
	add_theme_support( 'wc-product-gallery-zoom' );
	add_theme_support( 'wc-product-gallery-lightbox' );
	add_theme_support( 'wc-product-gallery-slider' );
}
add_action( 'after_setup_theme', 'katerina_woo_support' );

/**
 * Add specific sidebar widgets.
 */
function katerina_woo_widgets_init() {
	register_sidebar(
		array(
			'name'          => esc_html__( 'WooCommerce Sidebar', 'katerina' ),
			'id'            => 'woo-sidebar',
			'description'   => esc_html__( 'Add widgets here to appear in your sidebar on WooCommerce shop pages.', 'katerina' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		)
	);
}
add_action( 'widgets_init', 'katerina_woo_widgets_init' );

/* Disable default plugin style in favor of theme style. */
add_filter( 'woocommerce_enqueue_styles', '__return_empty_array' );

/**
 * Use own theme custom style.
 */
function katerina_woo_scripts_and_style() {
	$katerina_theme_version = wp_get_theme()->get( 'Version' );

	wp_enqueue_style( 'katerina-woocommerce', get_template_directory_uri() . '/assets/css/woocommerce.css', array(), $katerina_theme_version );
}
add_action( 'wp_enqueue_scripts', 'katerina_woo_scripts_and_style', 11 );

/* Override layout with proper hooks. */
remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10 );
remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10 );
remove_action( 'woocommerce_sidebar', 'woocommerce_get_sidebar', 10 );
remove_action( 'wp_footer', 'woocommerce_demo_store' );
remove_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_rating', 5 );
remove_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 10 );
remove_action( 'woocommerce_before_main_content', 'woocommerce_breadcrumb', 20, 0 );
remove_action( 'woocommerce_archive_description', 'woocommerce_taxonomy_archive_description', 10 );
remove_action( 'woocommerce_archive_description', 'woocommerce_product_archive_description', 10 );
remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_meta', 40 );

add_action( 'woocommerce_before_shop_loop_item', 'woocommerce_show_product_loop_sale_flash', 8 );

/**
 * Modify pagination style.
 */
function woocommerce_pagination() {
	if ( ! wc_get_loop_prop( 'is_paginated' ) || ! woocommerce_products_will_display() ) {
		return;
	}

	$args = array(
		'total'   => wc_get_loop_prop( 'total_pages' ),
		'current' => wc_get_loop_prop( 'current_page' ),
		'base'    => esc_url_raw( add_query_arg( 'product-page', '%#%', false ) ),
		'format'  => '?product-page=%#%',
		'type'    => 'plain',
		'before_page_number' => '<span class="screen-reader-text">' . esc_html__( 'Page', 'katerina' ) . ' </span>',
		'prev_text' => katerina_get_svg( 'arrow-' . ( is_rtl() ? 'right' : 'left' ) ) . '<span class="screen-reader-text">' . esc_html__( 'Previous Page', 'katerina' ) . ' </span>',
		'next_text' => '<span class="screen-reader-text">' . esc_html__( 'Next Page', 'katerina' ) . ' </span>' . katerina_get_svg( 'arrow-' . ( is_rtl() ? 'left' : 'right' ) ),
	);

	if ( $args['total'] <= 1 ) {
		return;
	}

	if ( ! wc_get_loop_prop( 'is_shortcode' ) ) {
		$args['format'] = '';
		$args['base']   = esc_url_raw( str_replace( 999999999, '%#%', remove_query_arg( 'add-to-cart', get_pagenum_link( 999999999, false ) ) ) );
	}

	echo '<div class="woocommerce-pagination"><h2 class="screen-reader-text">' . esc_html__( 'Products navigation', 'katerina' ) . '</h2>' . paginate_links( $args ) . '</div>';
}

/**
 * Remove page title at user's discretion.
 */
function katerina_woo_show_page_title() {
	return false;
}
add_filter( 'woocommerce_show_page_title', 'katerina_woo_show_page_title' );

/**
 * Add container element for result count, select order & search form
 */
function woocommerce_result_count_before() {
	?>
	<div class="shop-filters">
	<?php
}
function woocommerce_catalog_ordering_after() {
	?>
	</div>
	<?php
}
add_action( 'woocommerce_before_shop_loop', 'woocommerce_result_count_before', 19 );
add_action( 'woocommerce_before_shop_loop', 'woocommerce_catalog_ordering_after', 32 );

function woocommerce_results_search() {
	if ( true == get_theme_mod( 'catalog_searchform', false ) ) {
		get_template_part( 'searchform', 'products' );
	}
}
add_action( 'woocommerce_before_shop_loop', 'woocommerce_results_search', 19 );

if ( ! function_exists( 'katerina_is_shop_sidebar_active' ) ) {
	function katerina_is_shop_sidebar_active() {
		global $wp_query;
		if ( $wp_query->is_singular ) {
			$katerina_current_post_id = $wp_query->queried_object_id;
		} elseif ( is_home() && ! is_front_page() ) {
			$katerina_current_post_id = get_option( 'page_for_posts' );
		} elseif ( class_exists( 'WooCommerce' ) && is_shop() ) {
			$katerina_current_post_id = get_option( 'woocommerce_shop_page_id' );
		}

		$is_sidebar_active  = is_active_sidebar( 'woo-sidebar' );
		$is_sidebar_allowed = is_shop() || is_product_category() || is_product_tag();

		if ( isset( $katerina_current_post_id ) ) {
			$page_sidebar = get_post_meta( $katerina_current_post_id, 'page_sidebar', true );
			if ( $is_sidebar_active && is_shop() ) {
				return ! empty( $page_sidebar );
			}
		}

		return $is_sidebar_active && $is_sidebar_allowed;
	}
}

/**
 * Wraps all WooCommerce content in wrappers which match the theme markup and add a left sidebar (if any).
 */
function katerina_woo_before_content() {
	$content_style = '';
	if ( is_shop() ) {
		$shop_id = get_option( 'woocommerce_shop_page_id' );
		$content_style = get_post_meta( $shop_id, 'content_style', true );
	}
	if ( empty( $content_style ) || 'hide' !== $content_style ) {
		get_template_part( 'template-parts/header/post-title', 'page' );
	}
	?>
	<div id="content" class="site-content">
		<div class="wrapper">
			<div class="entry-content">
				<?php if ( ! katerina_is_shop_sidebar_active() ) : ?>
				<div class="alignwide">
				<?php endif; ?>
	<?php
	woocommerce_demo_store();
	if ( ! is_checkout() ) {
		echo wp_kses_post( do_shortcode( '[woocommerce_messages]' ) );
	}
}
add_action( 'woocommerce_before_main_content', 'katerina_woo_before_content', 10 );

/**
 * Closes the wrapping divs and add a right sidebar (if any).
 */
function katerina_woo_after_content() {
	?>
				<?php if ( ! katerina_is_shop_sidebar_active() ) : ?>
				</div>
				<?php endif; ?>
			</div>
			<?php get_sidebar( 'woocommerce' ); ?>
		</div>
	</div>
	<?php
}
add_action( 'woocommerce_after_main_content', 'katerina_woo_after_content', 10 );

if ( ! function_exists( 'woocommerce_product_loop_start' ) ) {
	/**
	 * Output start markup for the product loop.
	 */
	function woocommerce_product_loop_start() {
		global $woocommerce_loop, $woocommerce;
		if ( version_compare( $woocommerce->version, '3.3', '<' ) ) {
			if ( empty( $woocommerce_loop['columns'] ) ) {
				$woocommerce_loop['columns'] = apply_filters( 'loop_shop_columns', katerina_loop_columns() );
			}
		}
		echo '<ul class="products clearfix columns-' . esc_attr( $woocommerce_loop['columns'] ) . '">';
	}
}

if ( ! function_exists( 'woocommerce_product_loop_end' ) ) {
	/**
	 * Output end markup for the product loop.
	 */
	function woocommerce_product_loop_end() {
		echo '</ul>';
	}
}

if ( ! function_exists( 'woocommerce_template_loop_add_to_cart' ) ) {
	/**
	 * Output add to cart link in the product loop.
	 */
	function woocommerce_template_loop_add_to_cart() {
		global $product;
		if ( ! $product->is_in_stock() ) {
			echo '<span class="out-of-stock">' . esc_html__( 'Out of stock', 'katerina' ) . '</span>';
			return;
		}

		if ( $product ) {
			echo apply_filters(
				'woocommerce_loop_add_to_cart_link',
				sprintf(
					'<a rel="nofollow" href="%s" data-quantity="1" data-product_id="%s" data-product_sku="%s" class="%s">%s</a>',
					esc_url( $product->add_to_cart_url() ),
					esc_attr( $product->get_id() ),
					esc_attr( $product->get_sku() ),
					esc_attr(
						implode(
							' ',
							array_filter(
								array(
									'button',
									'product_type_' . WC_Product_Factory::get_product_type( $product->get_id() ),
									$product->is_purchasable() && $product->is_in_stock() ? 'add_to_cart_button' : '',
									$product->supports( 'ajax_add_to_cart' ) ? 'ajax_add_to_cart' : '',
								)
							)
						)
					),
					esc_html( $product->add_to_cart_text() )
				),
				$product
			);
		}
	}
}

function katerina_loop_columns() {
	global $woocommerce;
	if ( version_compare( $woocommerce->version, '3.3', '<' ) ) {
		return 2;
	} else {
		return get_option( 'woocommerce_catalog_columns', 2 );
	}
}

/**
 * Set columns for the related products section.
 */
function katerina_woo_output_related_products_args() {
	global $woocommerce_loop;
	$woocommerce_loop['loop'] = 0;
	return array(
		'posts_per_page' => katerina_loop_columns(),
		'columns'        => katerina_loop_columns(),
		'orderby'        => 'rand',
	);
}
add_filter( 'woocommerce_output_related_products_args', 'katerina_woo_output_related_products_args' );

/**
 * Set columns for the upsell section.
 */
function katerina_woo_upsell_display_args() {
	global $woocommerce_loop;
	$woocommerce_loop['loop'] = 0;
	return array(
		'posts_per_page' => -1,
		'columns'        => katerina_loop_columns(),
		'orderby'        => 'rand',
	);
}
add_filter( 'woocommerce_upsell_display_args', 'katerina_woo_upsell_display_args' );

if ( ! function_exists( 'katerina_menu_cart_output' ) ) {
	function katerina_menu_cart_output() {
		if ( 1 === get_theme_mod( 'cart_in_menu', 1 ) ) {
			global $woocommerce;
			$cart_items_total = '';
			if ( $woocommerce->cart->get_cart_contents_count() > 0 ) {
				$cart_items_total = '<span class="cart-total">' . $woocommerce->cart->get_cart_contents_count() . '</span>';
			}

			return '<li id="katerina-menu-cart" class="menu-item-cart"><a href="' . esc_url( wc_get_cart_url() ) . '" title="' . esc_html__( 'View shopping cart', 'katerina' ) . '">' . katerina_get_svg( 'cart' ) . '<span class="cart-text">' . esc_html__( 'Shopping Cart', 'katerina' ) . '</span>' . $cart_items_total . '</a></li>';
		}

		return '';
	}
}

function katerina_nav_menu_items_cart( $items, $args ) {
	if ( ( has_nav_menu( 'primary' ) && 'primary' === $args->theme_location ) ) {
		return $items . katerina_menu_cart_output();
	}
	return $items;
}
add_filter( 'wp_nav_menu_items', 'katerina_nav_menu_items_cart', 13, 2 );

/* Ensure cart contents update when products are added to the cart via AJAX */
function katerina_header_add_to_cart_fragment( $fragments ) {
	$fragments['#katerina-menu-cart'] = katerina_menu_cart_output();
	return $fragments;
}
add_filter( 'woocommerce_add_to_cart_fragments', 'katerina_header_add_to_cart_fragment' );

/* add container around product thumbnail */
function katerina_woo_before_shop_loop_item( $a ) {
	echo '<div class="thumb"><span class="photo">';
}
add_action( 'woocommerce_before_shop_loop_item', 'katerina_woo_before_shop_loop_item', 9, 1 );

function katerina_woo_before_shop_loop_item_title() {
	echo '</a></span><a href="' . esc_url( get_permalink() ) . '" class="product-title">';
}
add_action( 'woocommerce_before_shop_loop_item_title', 'katerina_woo_before_shop_loop_item_title', 20 );

function katerina_woo_after_shop_loop_item() {
	echo '</div>';
}
add_action( 'woocommerce_after_shop_loop_item', 'katerina_woo_after_shop_loop_item', 15 );

remove_action( 'woocommerce_shop_loop_item_title', 'woocommerce_template_loop_product_title', 10 );
remove_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_price', 10 );

function katerina_woo_template_loop_product_title() {
	global $product;
	$price      = '';
	$price_html = $product->get_price_html();
	if ( ! empty( $price_html ) ) {
		$price = '<span class="price">' . $price_html . '</span>';
	}
	echo '<span class="title">' . get_the_title() . '</span>' . $price;
}
add_action( 'woocommerce_shop_loop_item_title', 'katerina_woo_template_loop_product_title', 10 );

/* add second image for products, if any exists */
function katerina_woo_template_loop_second_product_thumbnail() {
	global $product, $woocommerce;
	$attachment_ids = $product->get_gallery_image_ids();
	if ( $attachment_ids && $product->is_in_stock() ) {
		$secondary_image_id      = $attachment_ids['0'];
		$secondary_image_attribs = array(
			'class' => 'secondary attachment-woocommerce_thumbnail size-woocommerce_thumbnail wp-post-image',
		);
		echo wp_get_attachment_image( $secondary_image_id, 'woocommerce_thumbnail', '', $secondary_image_attribs );
	}
}
add_action( 'woocommerce_before_shop_loop_item_title', 'katerina_woo_template_loop_second_product_thumbnail', 15 );

/* move add to cart button in loop, inside thumb showed on hover */
remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_add_to_cart', 10 );
// add_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_add_to_cart', 11 );

function katerina_woo_template_loop_add_to_cart() {
	woocommerce_template_loop_add_to_cart();
}
add_action( 'woocommerce_before_shop_loop_item_title', 'katerina_woo_template_loop_add_to_cart', 16 );

/* no title for single product view, as it is already displayed in the header by the theme */
remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_title', 5 );
remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_rating', 10 );
add_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_rating', 20 );

/* Add some wrappers around the single product view gallery and description */
function katerina_woo_before_single_product_summary_before() {
	echo '<div class="product-gallery-summary"><div class="product-gallery">';
}
add_action( 'woocommerce_before_single_product_summary', 'katerina_woo_before_single_product_summary_before', 5 );
function katerina_woo_before_single_product_summary_after() {
	echo '</div><div class="product-summary">';
}
add_action( 'woocommerce_before_single_product_summary', 'katerina_woo_before_single_product_summary_after', 22 );
function katerina_woo_after_single_product_summary() {
	echo '</div></div>';
}
add_action( 'woocommerce_after_single_product_summary', 'katerina_woo_after_single_product_summary', 5 );

function katerina_woo_composited_product_image_html( $output, $post_ID ) {
	return $output;
}
add_filter( 'woocommerce_composited_product_image_html', 'katerina_woo_composited_product_image_html', 10, 2 );

function katerina_woo_before_quantity_input_field() {
	?>
	<span class="decrease">
		<?php katerina_theme_svg( 'minus' ); ?>
	</span>
	<?php
}
add_action( 'woocommerce_before_quantity_input_field', 'katerina_woo_before_quantity_input_field', 10 );

function katerina_woo_after_quantity_input_field() {
	?>
	<span class="increase">
		<?php katerina_theme_svg( 'plus' ); ?>
	</span>
	<?php
}
add_action( 'woocommerce_after_quantity_input_field', 'katerina_woo_after_quantity_input_field', 10 );

/**
 * Add shop specific Customizer settings and controls.
 */
function katerina_shop_customize_register( $wp_customize ) {

	// Display search form in product listing filter section.
	$wp_customize->add_setting(
		'catalog_searchform',
		array(
			'capability'        => 'edit_theme_options',
			'default'           => 0,
			'sanitize_callback' => 'absint',
		)
	);
	$wp_customize->add_control(
		'catalog_searchform',
		array(
			'label'       => esc_html__( 'Enable search form filter', 'katerina' ),
			'settings'    => 'catalog_searchform',
			'section'     => 'woocommerce_product_catalog',
			'type'        => 'checkbox',
		)
	);

	/* Other options section */
	$wp_customize->add_section(
		'woocommerce_theme_options',
		array(
			'title'      => esc_html__( 'Additional Theme Options', 'katerina' ),
			'panel'      => 'woocommerce',
			'capability' => 'edit_theme_options',
		)
	);

	// Show reading time for blog posts
	$wp_customize->add_setting(
		'cart_in_menu',
		array(
			'default'           => 1,
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'absint',
		)
	);
	$wp_customize->add_control(
		'cart_in_menu',
		array(
			'label'       => esc_html__( 'Shopping Cart', 'katerina' ),
			'description' => esc_html__( 'Show the shopping cart icon in the primary menu.', 'katerina' ),
			'settings'    => 'cart_in_menu',
			'section'     => 'woocommerce_theme_options',
			'type'        => 'checkbox',
		)
	);

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial(
			'cart_in_menu',
			array(
				'selector'            => '.main-navigation .menu-item-cart',
				'container_inclusive' => false,
				'fallback_refresh'    => false,
			)
		);
	}

}
add_action( 'customize_register', 'katerina_shop_customize_register', 11 );
