<?php
/**
 * Displays featured content part for pages.
 */

// Get current post id.
global $wp_query;
if ( $wp_query->is_singular ) {
	$katerina_current_post_id = $wp_query->queried_object_id;
} elseif ( is_home() && ! is_front_page() ) {
	$katerina_current_post_id = get_option( 'page_for_posts' );
} elseif ( class_exists( 'WooCommerce' ) && is_shop() ) {
	$katerina_current_post_id = get_option( 'woocommerce_shop_page_id' );
}

$featured_area_type              = false;
$featured_area_no_overlay        = false;
$featured_area_no_social         = false;
$featured_area_no_scroll_content = false;
$featured_general_text           = false;
$featured_area_text              = false;
$featured_area_custom            = false;
$custom_slider                   = false;
$content_style                   = false;
if ( isset( $katerina_current_post_id ) ) {
	$featured_area_type = get_post_meta( $katerina_current_post_id, 'featured_area_type', true );
	$featured_area_no_overlay = get_post_meta( $katerina_current_post_id, 'featured_area_no_overlay', true );
	$featured_general_text = get_post_meta( $katerina_current_post_id, 'featured_general_text', true );
	if ( 'slider' !== $featured_area_type ) {
		$featured_area_text = get_post_meta( $katerina_current_post_id, 'featured_area_text', true );
	}
	$featured_area_no_social = get_post_meta( $katerina_current_post_id, 'featured_area_no_social', true );
	$featured_area_no_scroll_content = get_post_meta( $katerina_current_post_id, 'featured_area_no_scroll_content', true );
	$featured_area_custom = get_post_meta( $katerina_current_post_id, 'custom_featured_area_html', true );
	$custom_slider = get_post_meta( $katerina_current_post_id, 'custom_featured_area', true );
	$content_style = get_post_meta( $katerina_current_post_id, 'content_style', true );
}

if ( is_404() ) {
	$featured_image_404       = get_theme_mod( 'featured_image_404', 0 );
	$featured_area_type       = '404';
	$featured_area_no_overlay = ( 0 === $featured_image_404 );
}

if ( ! empty( $featured_area_type ) || is_404() ) :
	?>

<header id="featured" class="site-featured type-<?php echo esc_attr( $featured_area_type ); ?>">
	<div id="featured-media" class="featured-media parallax-hover<?php echo esc_attr( $featured_area_no_overlay ? '' : ' has-overlay' ); ?>">
		<?php if ( is_404() ) : ?>
			<?php if ( 0 !== $featured_image_404 ) : ?>
				<div id="featured-slider" class="featured-slider type-image">
					<?php echo wp_get_attachment_image( $featured_image_404, 'full', false, array( 'loading' => false ) ); // escapted by WP; ?>
				</div>
			<?php endif; ?>
			<div class="featured-text">
				<div class="wrapper">
					<h1 class="featured-title display"><span><?php esc_html_e( 'Error', 'katerina' ); ?></span> 4<em>0</em>4</h1>
					<p class="featured-description"><?php esc_html_e( 'Apologies, but no results were found for the requested page.', 'katerina' ); ?></p>
				</div>
			</div>
		<?php else : ?>
			<?php if ( $featured_general_text ) : ?>
				<div class="generic-information">
					<?php echo wp_kses_post( wpautop( do_shortcode( $featured_general_text ) ) ); ?>
				</div>
			<?php endif; ?>
			<?php if ( 'featured' === $featured_area_type && has_post_thumbnail( $katerina_current_post_id ) ) : ?>
				<div id="featured-slider" class="featured-slider type-image">
					<?php echo get_the_post_thumbnail( $katerina_current_post_id, 'full', array( 'loading' => false ) ); ?>
				</div>
			<?php endif; ?>
			<?php
			if ( 'slider' === $featured_area_type && ! empty( $custom_slider ) ) :
				$slider_displacement = get_post_meta( $katerina_current_post_id, 'slider_displacement', true );
				if ( ! $slider_displacement ) {
					$slider_displacement = get_theme_file_uri( '/assets/images/displacement-map.png' );
				}
				$slider_displacement_intensity = get_post_meta( $katerina_current_post_id, 'slider_displacement_intensity', true );
				$slider_transition = get_post_meta( $katerina_current_post_id, 'slider_transition', true );
				$slider_automatic = get_post_meta( $katerina_current_post_id, 'slider_automatic', true );
				$slider_automatic_speed = get_post_meta( $katerina_current_post_id, 'slider_automatic_speed', true );
				$slider_automatic_initial_delay = get_post_meta( $katerina_current_post_id, 'slider_automatic_initial_delay', true );
				$slider_hoverpause = get_post_meta( $katerina_current_post_id, 'slider_hoverpause', true );
				$slider_keyboardnav = get_post_meta( $katerina_current_post_id, 'slider_keyboardnav', true );
				$slider_touchnav = get_post_meta( $katerina_current_post_id, 'slider_touchnav', true );
				?>
				<div id="featured-slider" class="featured-slider type-displacement" data-displacement="<?php echo esc_url( $slider_displacement ); ?>"<?php if ( $slider_displacement_intensity ) : ?> data-intensity="<?php echo esc_attr( $slider_displacement_intensity / 100 ); ?>"<?php endif; if ( $slider_transition ) : ?> data-transition="<?php echo esc_attr( $slider_transition ); ?>"<?php endif; if ( $slider_automatic ) : ?> data-automatic="1"<?php endif; if ( '' !== $slider_automatic_speed ) : ?> data-automatic_speed="<?php echo esc_attr( $slider_automatic_speed ); ?>"<?php endif; if ( '' !== $slider_automatic_initial_delay ) : ?> data-automatic_initial_delay="<?php echo esc_attr( $slider_automatic_initial_delay ); ?>"<?php endif; if ( $slider_hoverpause ) : ?> data-hoverpause="1"<?php endif; if ( $slider_keyboardnav ) : ?> data-keyboardnav="0"<?php endif; if ( $slider_touchnav ) : ?> data-touchnav="0"<?php endif; ?>>
					<?php
					$first_slide         = true;
					$first_slide_caption = '';
					foreach ( $custom_slider as $slide ) {
						switch ( $slide['type'] ) {
							case 'image':
								?>
								<div class="slide<?php echo esc_attr( $first_slide ? ' is-active' : '' ); ?>">
									<?php
									if ( isset( $slide['image'] ) ) {
										echo wp_get_attachment_image( $slide['image'], 'full', false, array( 'loading' => false ) ); // escapted by WP
									}
									if ( isset( $slide['caption'] ) ) :
										?>
										<div class="slide-content">
											<?php
											$slide_caption = wpautop( do_shortcode( $slide['caption'] ) );
											if ( $first_slide ) {
												$first_slide_caption = $slide_caption;
											}
											echo wp_kses_post( $slide_caption ); ?>
										</div>
									<?php endif; ?>
								</div>
								<?php
								$first_slide = false;
								break;
						}
					}
					?>
				</div>
				<div class="featured-slider-controls">
					<a href="#" class="prev"><?php katerina_theme_svg( 'chevron-left' ); ?></a><a href="#" class="next"><?php katerina_theme_svg( 'chevron-right' ); ?></a><span class="progress"></span>
				</div>
				<div class="featured-text">
					<div class="wrapper">
						<?php echo wp_kses_post( $first_slide_caption ); ?>
					</div>
				</div>
			<?php endif; ?>
			<?php if ( 'video' === $featured_area_type ) : ?>
				<div id="featured-slider" class="featured-slider type-video">
					<?php echo wp_kses( do_shortcode( $featured_area_custom ), 'katerina-featured' ); ?>
				</div>
			<?php endif; ?>
			<?php if ( 'html' === $featured_area_type ) : ?>
				<?php echo do_shortcode( $featured_area_custom ); ?>
			<?php endif; ?>
			<?php if ( $featured_area_text && 'slider' !== $featured_area_type ) : ?>
				<div class="featured-text">
					<div class="wrapper">
						<?php echo wp_kses_post( wpautop( do_shortcode( $featured_area_text ) ) ); ?>
					</div>
				</div>
			<?php endif; ?>
			<?php
			if ( ! $featured_area_no_social ) {
				get_template_part( 'template-parts/navigation/navigation', 'social' );
			}
			?>
			<?php if ( 'hide' !== $content_style && ! $featured_area_no_scroll_content ) : ?>
				<a href="#top-header" id="scroll-to-header" class="scroll-to-header" title="<?php esc_attr_e( 'Scroll to the content', 'katerina' ); ?>"></a>
			<?php endif; ?>
			<span class="loading-spinner"><?php katerina_theme_svg( 'loading' ); ?></span>
		<?php endif; ?>
	</div>
</header>
<?php
endif;
