<?php
/**
 * Template part for displaying posts.
 */

// try to override the permalink, if this is a 'link' post type
$katerina_post_link = get_permalink();
$katerina_post_icon = '';
if ( 'link' === get_post_format() ) {
	$katerina_post_content = get_the_content();
	if ( preg_match( "/<a\s[^>]*href=([\"\']??)([^\\1 >]*?)\\1[^>]*>(.*)<\/a>/siU", $katerina_post_content, $matches ) ) {
		if ( isset( $matches[2] ) ) {
			$katerina_post_link = $matches[2];
		}
	}
}

if ( is_sticky() && 1 === max( 1, get_query_var( 'paged' ) ) ) {
	$katerina_post_icon = katerina_get_svg( 'pin' );
} else {
	switch ( get_post_format() ) {
		case 'image':
		case 'gallery':
		case 'audio':
		case 'video':
		case 'quote':
		case 'status':
		case 'chat':
			$katerina_post_icon = katerina_get_svg( 'post-' . get_post_format() );
			break;

		case 'link':
			$katerina_post_icon = katerina_get_svg( 'link-exterior' );
			break;
	}
}

$katerina_categories_list = get_the_category_list( '<span>' . esc_html__( ', ', 'katerina' ) . '</span>' );
?>

<article id="post-<?php the_ID(); ?>" <?php post_class( 'entry entry-post' ); ?>>

	<?php if ( '' !== get_the_post_thumbnail() ) : ?>
		<div class="entry-media entry-image parallax-hover">
			<a href="<?php echo esc_url( $katerina_post_link ); ?>">
				<?php the_post_thumbnail( 'large' ); ?>
				<span class="view-more">
					<?php
					echo wp_kses_post( katerina_listing_read_more_string() );
					katerina_theme_svg( 'arrow-right-long' );
					?>
				</span>
				<?php if ( 'post' === get_post_type() ) : ?>
					<span class="meta"><span class="meta-reading-time"><?php katerina_theme_svg( 'clock' ); echo katerina_estimated_reading_time(); ?></span></span>
				<?php endif; ?>
			</a>
		</div>
	<?php endif; ?>

	<header class="entry-header">
		<?php
		the_title(
			sprintf( '<h3 class="entry-title"><a href="%s" rel="bookmark">' . $katerina_post_icon, esc_attr( esc_url( $katerina_post_link ) ) ),
			'</a></h3>'
		);
		?>
		<?php if ( 'post' === get_post_type() ) : ?>
			<div class="meta-date"><?php katerina_posted_on(); ?></div>
			<?php if ( $katerina_categories_list && katerina_categorized_blog() ) : ?>
				<span class="meta-categories<?php echo esc_attr( substr_count( $katerina_categories_list, 'rel="category' ) > 2 ? ' more-then-two' : '' ); ?>">
					<?php katerina_theme_svg( 'folder' ); ?>
					<span class="screen-reader-text"><?php esc_html_e( 'Posted in: ', 'katerina' ); ?></span>
					<?php echo wp_kses_post( $katerina_categories_list ); ?>
				</span>
			<?php endif; ?>
		<?php endif; ?>
	</header>

	<?php if ( ! post_password_required() ) : ?>
		<div class="entry-content">
			<div class="entry-excerpt">
				<?php the_excerpt(); ?>
			</div>
		</div>
	<?php endif; ?>

</article>
